# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "survival", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(survival) #for clogit
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter10_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter10_application")

txtStart("bes1992_analysis_R.txt")

#---- Load in data ----
data <- read_dta('bes1992_small.dta')

#---- Variable description  ----
names(data)
describe(data)

#---- Do men and women hold different positions on our three policy	dimensions? ----
data <- data[order(data$female), ]

# Defense
describe(data$defense_self)
defense_sd <- describe(data$defense_self)$sd; defense_sd

describe(data$defense_self[data$female==0])
defense_male <- describe(data$defense_self[data$female==0])$mean; defense_male

describe(data$defense_self[data$female==1])
defense_fem <- describe(data$defense_self[data$female==1])$mean; defense_fem

defense_fem-defense_male
((defense_fem-defense_male)/defense_sd)*100

t.test(data$defense_self ~ data$female)

# Government intervention
describe(data$gov_intervention_self2)
gov_sd <- describe(data$gov_intervention_self2)$sd; gov_sd

describe(data$gov_intervention_self2[data$female==0])
gov_male <- describe(data$gov_intervention_self2[data$female==0])$mean; gov_male

describe(data$gov_intervention_self2[data$female==1])
gov_fem <- describe(data$gov_intervention_self2[data$female==1])$mean; gov_fem

gov_fem-gov_male
((gov_fem-gov_male)/gov_sd)*100

t.test(data$gov_intervention_self2 ~ data$female)

# Women's rights
describe(data$womensrights_self)
women_sd <- describe(data$womensrights_self)$sd; women_sd

describe(data$womensrights_self[data$female==0])
women_male <- describe(data$womensrights_self[data$female==0])$mean; women_male

describe(data$womensrights_self[data$female==1])
women_fem <- describe(data$womensrights_self[data$female==1])$mean; women_fem

women_fem-women_male
((women_fem-women_male)/women_sd)*100

t.test(data$womensrights_self ~ data$female)

#---- Produce results shown in Table 10.4 in Chapter 10 ----
mod1 <- clogit(choice ~ defense_distance + female_defense + gov_intervention_distance + 
         female_gov_intervention + less_womensrights_distance + female_less_womensrights +
         female1 + female3 + age1 + age3 + workingclass1 + workingclass3 + income_other1 +
         income_other3 + education1 + education3 + trade_union1 + trade_union3 + 
         alternative1 + alternative3 + strata(respondent_id), data)
mod1

#---- Number of individuals	----
mod1$n/3

#---- Compare coefficients on ideological distance variables ----
(mod1$coefficients[1]/mod1$coefficients[3]-1)*100
(mod1$coefficients[1]/mod1$coefficients[5]-1)*100

summary(glht(mod1, linfct = c("defense_distance - gov_intervention_distance = 0")))
confint(summary(glht(mod1, linfct = c("defense_distance - gov_intervention_distance = 0"))))

summary(glht(mod1, linfct = c("defense_distance - less_womensrights_distance = 0")))
confint(summary(glht(mod1, linfct = c("defense_distance - less_womensrights_distance = 0"))))

#---- Modifying effect of gender on salience of defense ----
summary(glht(mod1, linfct = c("female_defense = 0")))
confint(summary(glht(mod1, linfct = c("female_defense = 0"))))

#---- Effect of increasing distance wrt defense on voter utility ----
# Men
summary(glht(mod1, linfct = c("defense_distance = 0")))
confint(summary(glht(mod1, linfct = c("defense_distance = 0"))))

# Women
summary(glht(mod1, linfct = c("defense_distance + female_defense = 0")))
confint(summary(glht(mod1, linfct = c("defense_distance + female_defense = 0"))))

#---- How much smaller is effect for women? ----
((mod1$coefficients[1] + mod1$coefficients[2])/mod1$coefficients[1]-1)*100

#---- Modifying effect of gender on salience of government intervention ----
summary(glht(mod1, linfct = c("female_gov_intervention = 0")))
confint(summary(glht(mod1, linfct = c("female_gov_intervention = 0"))))

#---- Effect of increasing distance wrt government intervention on voter utility	----
summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))
confint(summary(glht(mod1, linfct = c("gov_intervention_distance = 0"))))

summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))
confint(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0"))))

((mod1$coefficients[3] + mod1$coefficients[4])/mod1$coefficients[3]-1)*100

#---- Modifying effect of gender on salience of women's rights ----
summary(glht(mod1, linfct = c("female_less_womensrights = 0")))
confint(summary(glht(mod1, linfct = c("female_less_womensrights = 0"))))

#---- Effect of increasing distance wrt women's rights on voter utility	----
summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))
confint(summary(glht(mod1, linfct = c("less_womensrights_distance = 0"))))

summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))
confint(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0"))))

((mod1$coefficients[5] + mod1$coefficients[6])/mod1$coefficients[5]-1)*100

#---- No difference in salience across issues for women	----
summary(glht(mod1, linfct = c("(gov_intervention_distance + female_gov_intervention) - 
                              (defense_distance + female_defense) = 0")))
confint(summary(glht(mod1, linfct = c("(gov_intervention_distance + female_gov_intervention) - 
                              (defense_distance + female_defense) = 0"))))

summary(glht(mod1, linfct = c("(gov_intervention_distance + female_gov_intervention) - 
                              (less_womensrights_distance + female_less_womensrights) = 0")))
confint(summary(glht(mod1, linfct = c("(gov_intervention_distance + female_gov_intervention) - 
                              (less_womensrights_distance + female_less_womensrights) = 0")))) 

#---- Produce a figure like Figure 10.1 in R showing how the effect of a one unit increase in ideological distance on voter utility varies by gender for each of the three issue areas. ----
plot3 <- matrix(NA, 9, 7)
colnames(plot3) <- c("estimate", "lo_95","hi_95", "se", "lo_90", "hi_90", "num")

#---- Grab information ----

# Defense
# Men

plot3[1, 1] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[3]])
plot3[1, 2] <- as.numeric(confint(glht(mod1, linfct = c("defense_distance = 0")))$confint[[2]])
plot3[1, 3] <- as.numeric(confint(glht(mod1, linfct = c("defense_distance = 0")))$confint[[3]])
plot3[1, 4] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[4]])
plot3[1, 5] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[4]])
plot3[1, 6] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("defense_distance = 0")))$test[[4]])

# Women
plot3[2, 1] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance + female_defense = 0")))$test[[3]])
plot3[2, 2] <- as.numeric(confint(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$confint[[2]])
plot3[2, 3] <- as.numeric(confint(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$confint[[3]])
plot3[2, 4] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$test[[4]])
plot3[2, 5] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$test[[4]])
plot3[2, 6] <- as.numeric(summary(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("defense_distance  + female_defense = 0")))$test[[4]])

# Interaction
plot3[3, 1] <- as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[3]])
plot3[3, 2] <- as.numeric(confint(glht(mod1, linfct = c("female_defense = 0")))$confint[[2]])
plot3[3, 3] <- as.numeric(confint(glht(mod1, linfct = c("female_defense = 0")))$confint[[3]])
plot3[3, 4] <- as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[4]])
plot3[3, 5] <- as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[4]])
plot3[3, 6] <- as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_defense = 0")))$test[[4]])

# Government intervention
# Men
plot3[4, 1] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[3]])
plot3[4, 2] <- as.numeric(confint(glht(mod1, linfct = c("gov_intervention_distance = 0")))$confint[[2]])
plot3[4, 3] <- as.numeric(confint(glht(mod1, linfct = c("gov_intervention_distance = 0")))$confint[[3]])
plot3[4, 4] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[4]])
plot3[4, 5] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[4]])
plot3[4, 6] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance = 0")))$test[[4]])

# Women
plot3[5, 1] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[3]])
plot3[5, 2] <- as.numeric(confint(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$confint[[2]])
plot3[5, 3] <- as.numeric(confint(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$confint[[3]])
plot3[5, 4] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[4]])
plot3[5, 5] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[4]])
plot3[5, 6] <- as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("gov_intervention_distance + female_gov_intervention = 0")))$test[[4]])

# Interaction
plot3[6, 1] <- as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[3]])
plot3[6, 2] <- as.numeric(confint(glht(mod1, linfct = c("female_gov_intervention = 0")))$confint[[2]])
plot3[6, 3] <- as.numeric(confint(glht(mod1, linfct = c("female_gov_intervention = 0")))$confint[[3]])
plot3[6, 4] <- as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[4]])
plot3[6, 5] <- as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[4]])
plot3[6, 6] <- as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_gov_intervention = 0")))$test[[4]])

# Women's rights
# Men
plot3[7, 1] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[3]])
plot3[7, 2] <- as.numeric(confint(glht(mod1, linfct = c("less_womensrights_distance = 0")))$confint[[2]])
plot3[7, 3] <- as.numeric(confint(glht(mod1, linfct = c("less_womensrights_distance = 0")))$confint[[3]])
plot3[7, 4] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[4]])
plot3[7, 5] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[4]])
plot3[7, 6] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance = 0")))$test[[4]])

# Women
plot3[8, 1] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[3]])
plot3[8, 2] <- as.numeric(confint(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$confint[[2]])
plot3[8, 3] <- as.numeric(confint(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$confint[[3]])
plot3[8, 4] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[4]])
plot3[8, 5] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[4]])
plot3[8, 6] <- as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("less_womensrights_distance + female_less_womensrights = 0")))$test[[4]])

# Interaction
plot3[9, 1] <- as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[3]])
plot3[9, 2] <- as.numeric(confint(glht(mod1, linfct = c("female_less_womensrights = 0")))$confint[[2]])
plot3[9, 3] <- as.numeric(confint(glht(mod1, linfct = c("female_less_womensrights = 0")))$confint[[3]])
plot3[9, 4] <- as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[4]])
plot3[9, 5] <- as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[3]]) -
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[4]])
plot3[9, 6] <- as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[3]]) +
  qnorm(0.95)*as.numeric(summary(glht(mod1, linfct = c("female_less_womensrights = 0")))$test[[4]])

plot3
plot3[ , 7] <- c(9:1)

#---- Produce Figure 10.1 using ggplot2----
ggplot(data.frame(plot3)) + 
geom_pointrange(aes(x = num, y = estimate, ymin = lo_95, ymax = hi_95)) +
  geom_pointrange(aes(x = num, y = estimate, ymin = lo_90, ymax = hi_90), size=1.2) +
  geom_hline(yintercept = 0, color = gray(1/2), lty = 2) +
  ylim(-1, 0.6) +
  labs(y = "Effect Size", x = "", shape = "", title = "") +
  theme_bw()  +
  annotate("text", y  = -0.70, x = 9.2, label = "-0.70") +  
  annotate("text", y  = -0.52, x = 8.2, label = "-0.52") +  
  annotate("text", y  =  0.18, x = 7.2, label = "0.18") +  
  annotate("text", y  = -0.42, x = 6.2, label = "-0.42") +  
  annotate("text", y  = -0.68, x = 5.2, label = "-0.68") +  
  annotate("text", y  = -0.26, x = 4.2, label = "-0.26") +  
  annotate("text", y  = -0.54, x = 3.2, label = "-0.54") +  
  annotate("text", y  = -0.42, x = 2.2, label = "-0.42") +  
  annotate("text", y  = -0.11, x = 1.2, label = "-0.11") +  
  coord_flip() + 
  scale_x_discrete(limits = c("Difference: Women's Rights x Female", 
                              "Effect of Women's Rights Distance among Women",
                              "Effect of Women's Rights Distance among Men",
                              "Difference: Government Intervention x Female",
                              "Effect of Government Intervention Distance among Women",
                              "Effect of Government Intervention Distance among Men",
                              "Difference: Defense Distance x Female",
                              "Effect of Defense Distance among Women",
                              "Effect of Defense Distance among Men"))

#---- Gender-Genderation Gap Possibility ----
mod2 <- clogit(choice ~ defense_distance + female_defense + gov_intervention_distance +
       female_gov_intervention + less_womensrights_distance + female_less_womensrights +
       female1 + female3 + postwar_birth1 + postwar_birth3 + female_postwar1 + 
       female_postwar3 + workingclass1 + workingclass3 + income_other1 + income_other3 +
       education1 + education3 + trade_union1 + trade_union3 + alternative1 + alternative3 +
       postwar_birth1 + postwar_birth3 + female_postwar1 + female_postwar3  + workingclass1 +
       workingclass3 + income_other1 + income_other3 + education1 + education3 + trade_union1 +
       trade_union3 + alternative1 + alternative3 + strata(respondent_id), data)
mod2

summary(glht(mod2, linfct = c("female1 = 0")))
confint(summary(glht(mod2, linfct = c("female1 = 0"))))

summary(glht(mod2, linfct = c("female1 + female_postwar1 = 0")))
confint(summary(glht(mod2, linfct = c("female1 + female_postwar1 = 0"))))

#---- Produce a figure like Figure 10.2 in R showing how the effect of being female on voter utility varies across the observed range of values for Government Intervention when Defense and Women's Rigts are set at their mean values for the Conservative Party.	----

#---- Get some information that we'll want.	----
table(data$defense_distance)
table(data$defense_distance[data$female==0])
table(data$defense_distance[data$female==1])

table(data$gov_intervention_distance[data$party_alternative==1])
table(data$gov_intervention_distance[data$party_alternative==1 & data$female==0])
table(data$gov_intervention_distance[data$party_alternative==1 & data$female==1])

table(data$less_womensrights_distance)
table(data$less_womensrights_distance[data$female==0])
table(data$less_womensrights_distance[data$female==1])

describe(data$defense_distance[data$party_alternative==1])
defense_mean_cons <- describe(data$defense_distance[data$party_alternative==1])$mean;defense_mean_cons

describe(data$less_womensrights_distance[data$party_alternative==1])
womensrights_mean_cons <- describe(data$less_womensrights_distance[data$party_alternative==1])$mean;womensrights_mean_cons

#---- Summarize model ----
mod1

vcov(mod1)
b1 <- mod1$coefficients[1]; b1
b2 <- mod1$coefficients[2]; b2
b3 <- mod1$coefficients[3]; b3
b4 <- mod1$coefficients[4]; b4
b5 <- mod1$coefficients[5]; b5
b6 <- mod1$coefficients[6]; b6
b7 <- mod1$coefficients[7]; b7
b8 <- mod1$coefficients[8]; b8
b9 <- mod1$coefficients[9]; b9
b10 <- mod1$coefficients[10]; b10
b11 <- mod1$coefficients[11]; b11
b12 <- mod1$coefficients[12]; b12
b13 <- mod1$coefficients[13]; b13
b14 <- mod1$coefficients[14]; b14
b15 <- mod1$coefficients[15]; b15
b16 <- mod1$coefficients[16]; b16
b17 <- mod1$coefficients[17]; b17
b18 <- mod1$coefficients[18]; b18
b19 <- mod1$coefficients[19]; b19
b20 <- mod1$coefficients[20]; b20

varb1 <- vcov(mod1)[1, 1]; varb1
varb2 <- vcov(mod1)[2, 2]; varb2
varb3 <- vcov(mod1)[3, 3]; varb3
varb4 <- vcov(mod1)[4, 4]; varb4
varb5 <- vcov(mod1)[5, 5]; varb5
varb6 <- vcov(mod1)[6, 6]; varb6
varb7 <- vcov(mod1)[7, 7]; varb7

covb1b3 <- vcov(mod1)[1, 3]; covb1b3
covb7b2 <- vcov(mod1)[7, 2]; covb7b2
covb7b4 <- vcov(mod1)[7, 4]; covb7b4
covb7b6 <- vcov(mod1)[7, 6]; covb7b6
covb2b4 <- vcov(mod1)[2, 4]; covb2b4
covb2b6 <- vcov(mod1)[2, 6]; covb2b6
covb4b6 <- vcov(mod1)[4, 6]; covb4b6

#---- Government intervention	----
mod1

#---- Get effect of being female for distinct values of Government Intervention using R's glht command.	----
summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                               female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                               female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*1 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*1 + female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*2 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*2 + female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*3 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*3 + female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*4 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*4 + female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*5 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*5 + female_less_womensrights*1.454641 = 0"))))

summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*6 + female_less_womensrights*1.454641 = 0")))
confint(summary(glht(mod1, linfct = c("female1 + female_defense*1.503319 + 
                              female_gov_intervention*6 + female_less_womensrights*1.454641 = 0"))))

#---- Now get effect of being female manually, treating Government Intervention as continuous ----
n <- 1:62
MV <- (n-1)/10
conbx_gov <- b7+b2*defense_mean_cons+b4*MV+b6*womensrights_mean_cons
consx_gov <- sqrt(varb7+varb2*(defense_mean_cons^2)+varb4*(MV^2) +
                    varb6*(womensrights_mean_cons^2)+2*defense_mean_cons*covb7b2+
                    2*MV*covb7b4+2*womensrights_mean_cons*covb7b6+2*defense_mean_cons*MV*covb2b4+
                    2*womensrights_mean_cons*defense_mean_cons*covb2b6+2*womensrights_mean_cons*MV*covb4b6)
z <- qnorm(0.975); z
lowerx <- conbx_gov-(z*consx_gov)
upperx <- conbx_gov+(z*consx_gov)

#---- Produce Figure 10.2	----
ggplot() +
  geom_line(aes(x = MV, y = conbx_gov)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/12.5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*12.5, name="Percentage of Observations")
  ) +
  xlab("Government Intervention Distance") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Produce Figure 10.3 was produced in pgfplots, not R.	However, we did need information for the histograms on the base	of Figure 10.3a and 10.3b. ----
table(data$party_alternative)
data2 <- data %>%
  filter(party_alternative == 1) %>%
  dplyr::select(defense_distance, gov_intervention_distance, less_womensrights_distance) %>%
  filter(!is.na(defense_distance) & !is.na(gov_intervention_distance) & !is.na(less_womensrights_distance))

#---- Figure 10.3a - When women's rights are 0 ----
describe(data2)
total <- describe(data2)$n[1]; total

data2 <- data2[order(data2$less_womensrights_distance, data2$defense_distance, data2$gov_intervention_distance), ]

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent000 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent000

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent010 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent010

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent020 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent020

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent030 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent030

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent040 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent040

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent050 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent050

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent060 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent060

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent100 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent100

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent110 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent110

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent120 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent120

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent130 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent130

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent140 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent140

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent150 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent150

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent160 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent160

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent200 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent200

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent210 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent210

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent220 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent220

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent230 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent230

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent240 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent240

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent250 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent250

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent260 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent260

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent300 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent300

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent310 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent310

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent320 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent320

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent330 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent330

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent340 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent340

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent350 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent350

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent360 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent360

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent400 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent400

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent410 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent410

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent420 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent420

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent430 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent430

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent440 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent440

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent450 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent450

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent460 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent460

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent500 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent500

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent510 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent510

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent520 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent520

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent530 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent530

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent540 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent540

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent550 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent550

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent560 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent560

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])
percent600 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==0])$n/total*100; percent600

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])
percent610 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==0])$n/total*100; percent610

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])
percent620 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==0])$n/total*100; percent620

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])
percent630 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==0])$n/total*100; percent630

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])
percent640 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==0])$n/total*100; percent640

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])
percent650 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==0])$n/total*100; percent650

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])
percent660 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==0])$n/total*100; percent660

#---- Figure 10.3b - When women's rights are 1 ----
describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent001 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent001

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent011 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent011

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent021 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent021

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent031 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent031

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent041 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent041

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent051 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent051

describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent061 <- describe(data2$defense_distance[data2$defense_distance==0 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent061

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent101 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent101

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent111 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent111

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent121 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent121

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent131 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent131

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent141 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent141

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent151 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent151

describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent161 <- describe(data2$defense_distance[data2$defense_distance==1 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent161

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent201 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent201

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent211 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent211

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent221 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent221

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent231 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent231

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent241 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent241

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent251 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent251

describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent261 <- describe(data2$defense_distance[data2$defense_distance==2 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent261

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent301 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent301

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent311 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent311

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent321 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent321

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent331 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent331

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent341 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent341

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent351 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent351

describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent361 <- describe(data2$defense_distance[data2$defense_distance==3 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent361

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent401 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent401

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent411 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent411

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent421 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent421

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent431 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent431

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent441 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent441

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent451 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent451

describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent461 <- describe(data2$defense_distance[data2$defense_distance==4 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent461

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent501 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent501

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent511 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent511

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent521 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent521

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent531 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent531

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent541 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent541

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent551 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent551

describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent561 <- describe(data2$defense_distance[data2$defense_distance==5 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent561

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])
percent601 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==0 & data2$less_womensrights_distance==1])$n/total*100; percent601

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])
percent611 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==1 & data2$less_womensrights_distance==1])$n/total*100; percent611

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])
percent621 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==2 & data2$less_womensrights_distance==1])$n/total*100; percent621

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])
percent631 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==3 & data2$less_womensrights_distance==1])$n/total*100; percent631

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])
percent641 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==4 & data2$less_womensrights_distance==1])$n/total*100; percent641

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])
percent651 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==5 & data2$less_womensrights_distance==1])$n/total*100; percent651

describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])
percent661 <- describe(data2$defense_distance[data2$defense_distance==6 & data2$gov_intervention_distance==6 & data2$less_womensrights_distance==1])$n/total*100; percent661

txtStop()