# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "survival", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(survival) #for clogit
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter10_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter10_application")

txtStart("bes1992_analysis2_R.txt")

#---- Load in data ----
data <- read_dta('bes1992_small.dta')

#---- Variable description  ----
names(data)
describe(data)

#---- Estimate model ----
mod1 <- clogit(choice ~ defense_distance + female_defense + gov_intervention_distance + 
         female_gov_intervention + less_womensrights_distance + female_less_womensrights +
         female1 + female3 + age1 + age3 + workingclass1 + workingclass3 + income_other1 +
         income_other3 + education1 + education3 + trade_union1 + trade_union3 + 
         alternative1 + alternative3 + strata(respondent_id), data)
mod1

#---- Get the information for making Table 10.5 in Chapter 10 ----

#---- Get some values for our baseline scenario ----
describe(data$income)
table(data$income)
describe(data$age)
table(data$age)
table(data$workingclass)
describe(data$education)
table(data$education)

describe(data$defense_distance[data$alternative1 == 1])
describe(data$defense_distance[data$alternative1 == 2])
describe(data$defense_distance[data$alternative1 == 3])

describe(data$gov_intervention_distance[data$alternative1 == 1])
describe(data$gov_intervention_distance[data$alternative1 == 2])
describe(data$gov_intervention_distance[data$alternative1 == 3])

describe(data$less_womensrights_distance[data$alternative1 == 1])
describe(data$less_womensrights_distance[data$alternative1 == 2])
describe(data$less_womensrights_distance[data$alternative1 == 3])

#---- We're interested in the marginal effect of increasing distance for government intervention for Conservative Party on the probability of voting for each of the parties ----
# Party 1: Conservatives, Party 2: Labour, Party 3: Lib Dems. Baseline party is Labour (2).	
mod1

set.seed(339487731)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))
describe(sim)

h_defense_distance1 <- 1
h_defense_distance2 <- 2
h_defense_distance3 <- 1

h_gov_intervention_distance1 <- 2
h_gov_intervention_distance2 <- 1
h_gov_intervention_distance3 <- 1

h_less_womensrights_distance1 <- 1
h_less_womensrights_distance2 <- 1
h_less_womensrights_distance3 <- 1

h_age <- 47
h_income <- 6
h_education <- 1
h_female <- 1
h_male <- 0
h_constant <- 1
h_workingclass <- 0
h_tradeunion <- 0

mod1

#---- Male voters ----
x_betahat_men_cons = sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_male +
  sim[, 3]*h_gov_intervention_distance1 + sim[, 4]*h_gov_intervention_distance1*h_male + 
  sim[, 5]*h_less_womensrights_distance1 + sim[, 6]*h_less_womensrights_distance1*h_male +
  sim[, 7]*h_male + sim[, 9]*h_age + sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education +
  sim[, 17]*h_tradeunion + sim[, 19]*h_constant

x_betahat_men_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_male + 
  sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_male + 
  sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_male

x_betahat_men_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_male +
  sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_male +
  sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_male +
  sim[, 8]*h_male + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income + sim[, 16]*h_education + 
  sim[, 18]*h_tradeunion + sim[, 20]*h_constant


e_betahat_men_cons <- exp(x_betahat_men_cons)
e_betahat_men_lab <- exp(x_betahat_men_lab)
e_betahat_men_libdem <- exp(x_betahat_men_libdem)

#---- Baseline predicted probability men	----
prob_cons_men <- e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_cons_men

prob_lab_men <- e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_lab_men

prob_libdem_men <- e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_libdem_men

describe(prob_cons_men)
describe(prob_lab_men)
describe(prob_libdem_men)

quantile(prob_cons_men, 0.025)
quantile(prob_cons_men, 0.975)
quantile(prob_lab_men, 0.025)
quantile(prob_lab_men, 0.975)
quantile(prob_libdem_men, 0.025)
quantile(prob_libdem_men, 0.975)

#----- Female voters -----
x_betahat_women_cons <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_female +
  sim[, 3]*h_gov_intervention_distance1 + sim[, 4]*h_gov_intervention_distance1*h_female +
  sim[, 5]*h_less_womensrights_distance1 + sim[, 6]*h_less_womensrights_distance1*h_female +
  sim[, 7]*h_female + sim[, 9]*h_age + sim[, 11]*h_workingclass + 
  sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion + sim[, 19]*h_constant
        
x_betahat_women_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_female +
  sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_female +
  sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_female

x_betahat_women_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_female +
  sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_female +
  sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_female +
  sim[, 8]*h_female + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income + 
  sim[, 16]*h_education + sim[, 18]*h_tradeunion + sim[, 20]*h_constant

e_betahat_women_cons <- exp(x_betahat_women_cons)
e_betahat_women_lab <- exp(x_betahat_women_lab)
e_betahat_women_libdem <- exp(x_betahat_women_libdem)

#---- Baseline predicted probability women ----
prob_cons_women <- e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_cons_women

prob_lab_women <- e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_lab_women

prob_libdem_women <- e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_libdem_women

describe(prob_cons_women)
describe(prob_lab_women)
describe(prob_libdem_women)

quantile(prob_cons_women, 0.025)
quantile(prob_cons_women, 0.975)
quantile(prob_lab_women, 0.025)
quantile(prob_lab_women, 0.975)
quantile(prob_libdem_women, 0.025)
quantile(prob_libdem_women, 0.975)

#---- Check probabilities sum to 1 ----
prob_cons_men + prob_lab_men + prob_libdem_men
prob_cons_women + prob_lab_women + prob_libdem_women

#---- Marginal effect ----

#---- (i) Conservative Party - men - direct marginal effect ----
me_cons_men = prob_cons_men*(1-prob_cons_men)*sim[, 3]
describe(me_cons_men)
quantile(me_cons_men, 0.025)
quantile(me_cons_men, 0.975)

#---- (ii) Conservative Party - women - direct marginal effect ----
me_cons_women = prob_cons_women*(1-prob_cons_women)*(sim[, 3] + sim[, 4])
describe(me_cons_women)
quantile(me_cons_women, 0.025)
quantile(me_cons_women, 0.975)

#---- (iii) Labour Party - men - cross-marginal effect ----
me_lab_men = -prob_cons_men*(prob_lab_men)*sim[, 3]
describe(me_lab_men)
quantile(me_lab_men, 0.025)
quantile(me_lab_men, 0.975)

#---- (iv) Labour Party - women - cross-marginal effect ----
me_lab_women = -prob_cons_women*(prob_lab_women)*(sim[, 3] + sim[, 4])
describe(me_lab_women)
quantile(me_lab_women, 0.025)
quantile(me_lab_women, 0.975)

#---- (v) Lib Dems - men - cross-marginal effect ----
me_libdem_men = -prob_cons_men*(prob_libdem_men)*sim[, 3]
describe(me_libdem_men)
quantile(me_libdem_men, 0.025)
quantile(me_libdem_men, 0.975)

#---- (vi) Lib Dems - women - cross-marginal effect ----
me_libdem_women = -prob_cons_women*(prob_libdem_women)*(sim[, 3] + sim[, 4])
describe(me_libdem_women)
quantile(me_libdem_women, 0.025)
quantile(me_libdem_women, 0.975)

#---- Check cross-marginal and direct marginal effects sum to 0 ----
me_cons_men+me_lab_men+me_libdem_men
me_cons_women+me_lab_women+me_libdem_women

#---- Interaction Effect: Modifying Effect of Gender ----
interaction_cons = me_cons_women - me_cons_men
describe(interaction_cons)
quantile(interaction_cons, 0.025)
quantile(interaction_cons, 0.975)
interaction_cons_percent = ((me_cons_women- me_cons_men)/me_cons_men)*100
describe(interaction_cons_percent)
quantile(interaction_cons_percent, 0.025)
quantile(interaction_cons_percent, 0.975)

interaction_lab = me_lab_women- me_lab_men
describe(interaction_lab)
quantile(interaction_lab, 0.025)
quantile(interaction_lab, 0.975)
interaction_lab_percent = ((me_lab_women- me_lab_men)/me_lab_men)*100
describe(interaction_lab_percent)
quantile(interaction_lab_percent, 0.025)
quantile(interaction_lab_percent, 0.975)

interaction_libdem = me_libdem_women- me_libdem_men
describe(interaction_libdem)
quantile(interaction_libdem, 0.025)
quantile(interaction_libdem, 0.975)
interaction_libdem_percent = ((me_libdem_women- me_libdem_men)/me_libdem_men)*100
describe(interaction_libdem_percent)
quantile(interaction_libdem_percent, 0.025)
quantile(interaction_libdem_percent, 0.975)

#---- Get the information for making Table 10.6 in Chapter 10	----

# Rather than marginal effects, let's look at the effect of a two
# unit increase in distance for government intervention for 
# Conservative Party on the probability of voting for each of the parties.
# We already have the probabilities in the baseline scenario. 
# We just need the probabilities in the counterfactual scenario and then the differences.

#---- What's an appropriate change in Conservative Party incongruence	on this dimension? ----
describe(data$gov_intervention_distance[data$alternative1==1])

#---- Move Conservative Party 2 units	----

#---- Male voters - counterfactual ----
x_betahat_men_cons2 <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_male +
  sim[, 3]*(h_gov_intervention_distance1+2) + sim[, 4]*(h_gov_intervention_distance1+2)*h_male +  
  sim[, 5]*h_less_womensrights_distance1 + sim[, 6]*h_less_womensrights_distance1*h_male + sim[, 7]*h_male +
  sim[, 9]*h_age + sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion +
  sim[, 19]*h_constant

x_betahat_men_lab2 <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_male + 
  sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_male + 
  sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_male

x_betahat_men_libdem2 <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_male + 
  sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_male +
  sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_male +
  sim[, 8]*h_male + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income +
  sim[, 16]*h_education + sim[, 18]*h_tradeunion + sim[, 20]*h_constant

e_betahat_men_cons2 <- exp(x_betahat_men_cons2)
e_betahat_men_lab2 <- exp(x_betahat_men_lab2)
e_betahat_men_libdem2 <- exp(x_betahat_men_libdem2)

#---- Predicted probability men - counterfactual ----
prob_cons_men2 <- e_betahat_men_cons2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2); prob_cons_men2
prob_lab_men2 <- e_betahat_men_lab2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2); prob_lab_men2
prob_libdem_men2 <- e_betahat_men_libdem2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2); prob_libdem_men2

describe(prob_cons_men2)
describe(prob_lab_men2)
describe(prob_libdem_men2)

quantile(prob_cons_men2, 0.025)
quantile(prob_cons_men2, 0.975)
quantile(prob_lab_men2, 0.025)
quantile(prob_lab_men2, 0.975)
quantile(prob_libdem_men2, 0.025)
quantile(prob_libdem_men2, 0.975)

diff_cons_men <- prob_cons_men2-prob_cons_men
diff_lab_men <- prob_lab_men2-prob_lab_men
diff_libdem_men <- prob_libdem_men2-prob_libdem_men

diff_cons_men_percent <- ((prob_cons_men2-prob_cons_men)/prob_cons_men)*100
diff_lab_men_percent <- ((prob_lab_men2-prob_lab_men)/prob_lab_men)*100
diff_libdem_men_percent <- ((prob_libdem_men2-prob_libdem_men)/prob_libdem_men)*100

describe(diff_cons_men)
describe(diff_lab_men)
describe(diff_libdem_men)
describe(diff_cons_men_percent)
describe(diff_lab_men_percent)
describe(diff_libdem_men_percent)

quantile(diff_cons_men, 0.025)
quantile(diff_cons_men, 0.975)
quantile(diff_lab_men, 0.025)
quantile(diff_lab_men, 0.975)
quantile(diff_libdem_men, 0.025)
quantile(diff_libdem_men, 0.975)
quantile(diff_cons_men_percent, 0.025)
quantile(diff_cons_men_percent, 0.975)
quantile(diff_lab_men_percent, 0.025)
quantile(diff_lab_men_percent, 0.975)
quantile(diff_libdem_men_percent, 0.025)
quantile(diff_libdem_men_percent, 0.975)

#---- Female voters - counterfactual ----
x_betahat_women_cons2 <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_female +
  sim[, 3]*(h_gov_intervention_distance1+2) + sim[, 4]*(h_gov_intervention_distance1+2)*h_female +
  sim[, 5]*h_less_womensrights_distance1 + sim[, 6]*h_less_womensrights_distance1*h_female +
  sim[, 7]*h_female + sim[, 9]*h_age + sim[, 11]*h_workingclass + sim[, 13]*h_income +
  sim[, 15]*h_education + sim[, 17]*h_tradeunion  + sim[, 19]*h_constant

x_betahat_women_lab2 <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_female +
  sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_female +
  sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_female

x_betahat_women_libdem2 <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_female +
  sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_female +
  sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_female +
  sim[, 8]*h_female + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income +
  sim[, 16]*h_education + sim[, 18]*h_tradeunion  + sim[, 20]*h_constant

e_betahat_women_cons2 <- exp(x_betahat_women_cons2)
e_betahat_women_lab2 <- exp(x_betahat_women_lab2)
e_betahat_women_libdem2 <- exp(x_betahat_women_libdem2)

#---- Predicted probability women - counterfactual ----
prob_cons_women2 <- e_betahat_women_cons2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2); prob_cons_women2
prob_lab_women2 <- e_betahat_women_lab2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2); prob_lab_women2
prob_libdem_women2 <- e_betahat_women_libdem2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2); prob_libdem_women2

describe(prob_cons_women2)
describe(prob_lab_women2)
describe(prob_libdem_women2)

quantile(prob_cons_women2, 0.025)
quantile(prob_cons_women2, 0.975)
quantile(prob_lab_women2, 0.025)
quantile(prob_lab_women2, 0.975)
quantile(prob_libdem_women2, 0.025)
quantile(prob_libdem_women2, 0.975)

diff_cons_women <- prob_cons_women2-prob_cons_women
diff_lab_women <- prob_lab_women2-prob_lab_women
diff_libdem_women <- prob_libdem_women2-prob_libdem_women

diff_cons_women_percent <- ((prob_cons_women2-prob_cons_women)/prob_cons_women)*100
diff_lab_women_percent <- ((prob_lab_women2-prob_lab_women)/prob_lab_women)*100
diff_libdem_women_percent <- ((prob_libdem_women2-prob_libdem_women)/prob_libdem_women)*100

describe(diff_cons_women)
describe(diff_lab_women)
describe(diff_libdem_women)
describe(diff_cons_women_percent)
describe(diff_lab_women_percent)
describe(diff_libdem_women_percent)

quantile(diff_cons_women, 0.025)
quantile(diff_cons_women, 0.975)
quantile(diff_lab_women, 0.025)
quantile(diff_lab_women, 0.975)
quantile(diff_libdem_women, 0.025)
quantile(diff_libdem_women, 0.975)
quantile(diff_cons_women_percent, 0.025)
quantile(diff_cons_women_percent, 0.975)
quantile(diff_lab_women_percent, 0.025)
quantile(diff_lab_women_percent, 0.975)
quantile(diff_libdem_women_percent, 0.025)
quantile(diff_libdem_women_percent, 0.975)

#---- Interaction Effect: Modifying Effect of Gender ----
interaction_cons2 = diff_cons_women- diff_cons_men
describe(interaction_cons2)
quantile(interaction_cons2, 0.025)
quantile(interaction_cons2, 0.975)
interaction_cons_percent2 = ((diff_cons_women- diff_cons_men)/diff_cons_men)*100
describe(interaction_cons_percent2)
quantile(interaction_cons_percent2, 0.025)
quantile(interaction_cons_percent2, 0.975)

interaction_lab2 = diff_lab_women- diff_lab_men
describe(interaction_lab2)
quantile(interaction_lab2, 0.025)
quantile(interaction_lab2, 0.975)
interaction_lab_percent2 = ((diff_lab_women- diff_lab_men)/diff_lab_men)*100
describe(interaction_lab_percent2)
quantile(interaction_lab_percent2, 0.025)
quantile(interaction_lab_percent2, 0.975)

interaction_libdem2 = diff_libdem_women- diff_libdem_men
describe(interaction_libdem2)
quantile(interaction_libdem2, 0.025)
quantile(interaction_libdem2, 0.975)
interaction_libdem_percent2 = ((diff_libdem_women- diff_libdem_men)/diff_libdem_men)*100
describe(interaction_libdem_percent2)
quantile(interaction_libdem_percent2, 0.025)
quantile(interaction_libdem_percent2, 0.975)

#---- Odds ratios	----
odds_men = exp(sim[, 3])
odds_men_percent = ((exp(sim[, 3]))-1)*100
describe(odds_men)
describe(odds_men_percent)
quantile(odds_men, 0.025)
quantile(odds_men, 0.975)
quantile(odds_men_percent, 0.025)
quantile(odds_men_percent, 0.975)

odds_women = exp(sim[, 3] + sim[, 4])
odds_women_percent = ((exp(sim[, 3] + sim[, 4]))-1)*100
describe(odds_women)
describe(odds_women_percent)
quantile(odds_women, 0.025)
quantile(odds_women, 0.975)
quantile(odds_women_percent, 0.025)
quantile(odds_women_percent, 0.975)

interaction= ((odds_women_percent-odds_men_percent)/odds_men_percent)*100
describe(interaction)
quantile(interaction, 0.025)
quantile(interaction, 0.975)

txtStop()