# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "survival", "msm", "TeachingDemos))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(survival) #for clogit
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter10_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter10_application")

txtStart("bes1992_analysis3_R.txt")

#---- Load in data ----
data <- read_dta('bes1992_small.dta')

names(data)
describe(data)

#---- Produce Figure 10.4 showing how the effect of being female on the probability of voting for the parties in the 1992 UK elections varies across the values for government intervention.	----

#---- Pick values for baseline scenario	----
h_defense_distance1 <- 1
h_defense_distance2 <- 2
h_defense_distance3 <- 1

h_gov_intervention_distance2 <- 1
h_gov_intervention_distance3 <- 1

h_less_womensrights_distance1 <- 1
h_less_womensrights_distance2 <- 1
h_less_womensrights_distance3 <- 1

h_age <- 47
h_income <- 6
h_education <- 1
h_female <- 1
h_male <- 0
h_constant <- 1
h_workingclass <- 0
h_tradeunion <- 0


#---- Estimate model ----
mod1 <- clogit(choice ~ defense_distance + female_defense + gov_intervention_distance + 
         female_gov_intervention + less_womensrights_distance + female_less_womensrights +
         female1 + female3 + age1 + age3 + workingclass1 + workingclass3 + income_other1 +
         income_other3 + education1 + education3 + trade_union1 + trade_union3 + 
         alternative1 + alternative3 + strata(respondent_id), data)
mod1

set.seed(339487731)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))

prob_hat0_cons <- vector()
lo0_cons <- vector()
hi0_cons <- vector()
prob_hat0_lab <- vector()
lo0_lab <- vector()
hi0_lab <- vector()
prob_hat0_libdem <- vector()
lo0_libdem <- vector()
hi0_libdem <- vector()
prob_hat1_cons <- vector()
lo1_cons <- vector()
hi1_cons <- vector()
prob_hat1_lab <- vector()
lo1_lab <- vector()
hi1_lab <- vector()
prob_hat1_libdem <- vector()
lo1_libdem <- vector()
hi1_libdem <- vector()
diff_hat_cons <- vector()
diff_lo_cons <- vector()
diff_hi_cons <- vector()
diff_hat_lab <- vector()
diff_lo_lab <- vector()
diff_hi_lab <- vector()
diff_hat_libdem <- vector()
diff_lo_libdem <- vector()
diff_hi_libdem <- vector()
percent_hat_cons <- vector()
percent_lo_cons <- vector()
percent_hi_cons <- vector()
percent_hat_lab <- vector()
percent_lo_lab <- vector()
percent_hi_lab <- vector()
percent_hat_libdem <- vector()
percent_lo_libdem <- vector()
percent_hi_libdem <- vector()

a <- 0
j <- 1
while(a <= 6.1){
  
  #---- Men - baseline ----
  x_betahat_men_cons <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_male + 
  sim[, 3]*a + sim[, 4]*a*h_male +  sim[, 5]*h_less_womensrights_distance1 + 
  sim[, 6]*h_less_womensrights_distance1*h_male + sim[, 7]*h_male + sim[, 9]*h_age + 
  sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion  + sim[, 19]*h_constant
  
  x_betahat_men_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_male +
    sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_male +
    sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_male
  
  x_betahat_men_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_male +
    sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_male +
    sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_male +
    sim[, 8]*h_male + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income + sim[, 16]*h_education + 
    sim[, 18]*h_tradeunion  + sim[, 20]*h_constant
  
  e_betahat_men_cons <- exp(x_betahat_men_cons)
  e_betahat_men_lab <- exp(x_betahat_men_lab)
  e_betahat_men_libdem <- exp(x_betahat_men_libdem)
  
  prob_cons_men <- e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  prob_lab_men <- e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  prob_libdem_men <- e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  
  probhat_cons_men <-mean(prob_cons_men)
  probhat_lab_men <-mean(prob_lab_men)
  probhat_libdem_men <-mean(prob_libdem_men)
  
  #---- Women - counterfactual ----
  x_betahat_women_cons <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_female +
  sim[, 3]*a + sim[, 4]*a*h_female +  sim[, 5]*h_less_womensrights_distance1 +
  sim[, 6]*h_less_womensrights_distance1*h_female + sim[, 7]*h_female + sim[, 9]*h_age +
  sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion  + sim[, 19]*h_constant

  x_betahat_women_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_female +
    sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_female +
    sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_female

  x_betahat_women_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_female +
    sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_female +
    sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_female +
    sim[, 8]*h_female + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income +
    sim[, 16]*h_education + sim[, 18]*h_tradeunion  + sim[, 20]*h_constant
 
  e_betahat_women_cons <- exp(x_betahat_women_cons)
  e_betahat_women_lab <- exp(x_betahat_women_lab)
  e_betahat_women_libdem <- exp(x_betahat_women_libdem)

  prob_cons_women <- e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
  prob_lab_women <- e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
  prob_libdem_women <- e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)

  probhat_cons_women <-mean(prob_cons_women)
  probhat_lab_women <-mean(prob_lab_women)
  probhat_libdem_women <-mean(prob_libdem_women)

  diff_cons<-prob_cons_women - prob_cons_men
  diff_lab<-prob_lab_women - prob_lab_men
  diff_libdem<-prob_libdem_women - prob_libdem_men

  diffhat_cons<-mean(diff_cons)
  diffhat_lab<-mean(diff_lab)
  diffhat_libdem<-mean(diff_libdem)

  diff_percent_cons<-(diff_cons/prob_cons_men)*100
  diff_percent_lab<-(diff_lab/prob_lab_men)*100
  diff_percent_libdem<-(diff_libdem/prob_libdem_men)*100

  diffhat_percent_cons<-mean(diff_percent_cons)
  diffhat_percent_lab<-mean(diff_percent_lab)
  diffhat_percent_libdem<-mean(diff_percent_libdem)
  
  lo0_cons[j] <- quantile(prob_cons_men, 0.025)
  hi0_cons[j] <- quantile(prob_cons_men, 0.975)
  
  lo0_lab[j] <- quantile(prob_lab_men, 0.025)
  hi0_lab[j] <- quantile(prob_lab_men, 0.975)
  
  lo0_libdem[j] <- quantile(prob_libdem_men, 0.025)
  hi0_libdem[j] <- quantile(prob_libdem_men, 0.975)
  
  lo1_cons[j] <- quantile(prob_cons_women, 0.025)
  hi1_cons[j] <- quantile(prob_cons_women, 0.975)
  
  lo1_lab[j] <- quantile(prob_lab_women, 0.025)
  hi1_lab[j] <- quantile(prob_lab_women, 0.975)
  
  lo1_libdem[j] <- quantile(prob_libdem_women, 0.025)
  hi1_libdem[j] <- quantile(prob_libdem_women, 0.975)
  
  diff_lo_cons[j] <- quantile(diff_cons, 0.025)
  diff_hi_cons[j] <- quantile(diff_cons, 0.975)
  
  diff_lo_lab[j] <- quantile(diff_lab, 0.025)
  diff_hi_lab[j] <- quantile(diff_lab, 0.975)
  
  diff_lo_libdem[j] <- quantile(diff_libdem, 0.025)
  diff_hi_libdem[j] <- quantile(diff_libdem, 0.975)
  
  percent_lo_cons[j] <- quantile(diff_percent_cons, 0.025)
  percent_hi_cons[j] <- quantile(diff_percent_cons, 0.975)
  
  percent_lo_lab[j] <- quantile(diff_percent_lab, 0.025)
  percent_hi_lab[j] <- quantile(diff_percent_lab, 0.975)
  
  percent_lo_libdem[j] <- quantile(diff_percent_libdem, 0.025)
  percent_hi_libdem[j] <- quantile(diff_percent_libdem, 0.975)
  
  prob_hat0_cons[j] <- probhat_cons_men
  prob_hat0_lab[j] <- probhat_lab_men
  prob_hat0_libdem[j] <- probhat_libdem_men
  prob_hat1_cons[j] <- probhat_cons_women
  prob_hat1_lab[j] <- probhat_lab_women
  prob_hat1_libdem[j] <- probhat_libdem_women
  diff_hat_cons[j] <- diffhat_cons
  diff_hat_lab[j] <- diffhat_lab
  diff_hat_libdem[j] <- diffhat_libdem
  percent_hat_cons[j] <- diffhat_percent_cons
  percent_hat_lab[j] <- diffhat_percent_lab
  percent_hat_libdem[j] <- diffhat_percent_libdem
  
  a <- a + 0.1
  j <- j + 1
  
}

#---- Let's make some marginal effect plots - Conservatives ----
sim_data <- as.data.frame(cbind(prob_hat0_cons, lo0_cons, hi0_cons, prob_hat0_lab, lo0_lab, hi0_lab, prob_hat0_libdem, lo0_libdem, hi0_libdem, prob_hat1_cons, lo1_cons, hi1_cons, prob_hat1_lab, lo1_lab, hi1_lab, prob_hat1_libdem, lo1_libdem, hi1_libdem, diff_hat_cons, diff_lo_cons, diff_hi_cons, diff_hat_lab, diff_lo_lab, diff_hi_lab, diff_hat_libdem, diff_lo_libdem, diff_hi_libdem, percent_hat_cons, percent_lo_cons, percent_hi_cons, percent_hat_lab, percent_lo_lab, percent_hi_lab, percent_hat_libdem, percent_lo_libdem, percent_hi_libdem))

sim_data <- sim_data[1:62, ]
n <- 1:62
MV <- (n-1)/10

#---- Similar to Figure 10.4a except that we use simulated point estimates	----
ggplot() +
  geom_line(aes(x = MV, y = diff_hat_cons)) +
  geom_line(aes(x = MV, y = diff_hi_cons), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_cons), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/300), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*300, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Similar to Figure 10.4b except that we use simulated point estimates	----
ggplot() +
  geom_line(aes(x = MV, y = percent_hat_cons)) +
  geom_line(aes(x = MV, y = percent_hi_cons), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_cons), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/1.5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*1.5, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Let's make some marginal effect plots - Labour ----

#---- Similar to Figure 10.4c except that we use simulated point estimates	----
ggplot() +
  geom_line(aes(x = MV, y = diff_hat_lab)) +
  geom_line(aes(x = MV, y = diff_hi_lab), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_lab), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/300), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*300, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Similar to Figure 10.4d except that we use simulated point estimates	----
ggplot() +
  geom_line(aes(x = MV, y = percent_hat_lab)) +
  geom_line(aes(x = MV, y = percent_hi_lab), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_lab), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100*5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./5, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Let's make some marginal effect plots - Lib Dem	----

#---- Similar to Figure 10.4e except that we use simulated point estimates	----

ggplot() +
  geom_line(aes(x = MV, y = diff_hat_libdem)) +
  geom_line(aes(x = MV, y = diff_hi_libdem), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_libdem), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/50), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*50, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Similar to Figure 10.4f except that we use simulated point estimates	----
ggplot() +
  geom_line(aes(x = MV, y = percent_hat_libdem)) +
  geom_line(aes(x = MV, y = percent_hi_libdem), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_libdem), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100*8), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./8,  name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- We recommend using the point estimates directly from the original coefficients rather than from the simulated coefficients ----

#---- So, let's get point estimates directly from coefficients ----
mod1

x_betahat_men_cons <- mod1$coefficients[1]*h_defense_distance1 + mod1$coefficients[2]*h_defense_distance1*h_male +
  mod1$coefficients[3]*MV + mod1$coefficients[4]*MV*h_male +
  mod1$coefficients[5]*h_less_womensrights_distance1 + 
  mod1$coefficients[6]*h_less_womensrights_distance1*h_male + mod1$coefficients[7]*h_male + 
  mod1$coefficients[9]*h_age + mod1$coefficients[11]*h_workingclass + mod1$coefficients[13]*h_income + 
  mod1$coefficients[15]*h_education + mod1$coefficients[17]*h_tradeunion  + mod1$coefficients[19]*h_constant

x_betahat_men_lab <- mod1$coefficients[1]*h_defense_distance2 + mod1$coefficients[2]*h_defense_distance2*h_male +
  mod1$coefficients[3]*h_gov_intervention_distance2 + 
  mod1$coefficients[4]*h_gov_intervention_distance2*h_male + 
  mod1$coefficients[5]*h_less_womensrights_distance2 + 
  mod1$coefficients[6]*h_less_womensrights_distance2*h_male

x_betahat_men_libdem <- mod1$coefficients[1]*h_defense_distance3 + mod1$coefficients[2]*h_defense_distance3*h_male +
  mod1$coefficients[3]*h_gov_intervention_distance3 +
  mod1$coefficients[4]*h_gov_intervention_distance3*h_male +
  mod1$coefficients[5]*h_less_womensrights_distance3 +
  mod1$coefficients[6]*h_less_womensrights_distance3*h_male + mod1$coefficients[8]*h_male + mod1$coefficients[10]*h_age +
  mod1$coefficients[12]*h_workingclass + mod1$coefficients[14]*h_income + mod1$coefficients[16]*h_education +
  mod1$coefficients[18]*h_tradeunion  + mod1$coefficients[20]*h_constant

e_betahat_men_cons <- exp(x_betahat_men_cons)
e_betahat_men_lab <- exp(x_betahat_men_lab)
e_betahat_men_libdem <- exp(x_betahat_men_libdem)

prob_cons_men <- e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
prob_lab_men <- e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
prob_libdem_men <- e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)

#---- Women - counterfactual ----
  
  x_betahat_women_cons <- mod1$coefficients[1]*h_defense_distance1 + mod1$coefficients[2]*h_defense_distance1*h_female +
  mod1$coefficients[3]*MV + mod1$coefficients[4]*MV*h_female +
  mod1$coefficients[5]*h_less_womensrights_distance1 + mod1$coefficients[6]*h_less_womensrights_distance1*h_female +
  mod1$coefficients[7]*h_female + mod1$coefficients[9]*h_age + mod1$coefficients[11]*h_workingclass + 
  mod1$coefficients[13]*h_income + mod1$coefficients[15]*h_education + mod1$coefficients[17]*h_tradeunion  +
  mod1$coefficients[19]*h_constant

x_betahat_women_lab <- mod1$coefficients[1]*h_defense_distance2 + mod1$coefficients[2]*h_defense_distance2*h_female +
  mod1$coefficients[3]*h_gov_intervention_distance2 + mod1$coefficients[4]*h_gov_intervention_distance2*h_female +
  mod1$coefficients[5]*h_less_womensrights_distance2 + mod1$coefficients[6]*h_less_womensrights_distance2*h_female

x_betahat_women_libdem <- mod1$coefficients[1]*h_defense_distance3 + mod1$coefficients[2]*h_defense_distance3*h_female +
  mod1$coefficients[3]*h_gov_intervention_distance3 + mod1$coefficients[4]*h_gov_intervention_distance3*h_female +
  mod1$coefficients[5]*h_less_womensrights_distance3 + mod1$coefficients[6]*h_less_womensrights_distance3*h_female +
  mod1$coefficients[8]*h_female + mod1$coefficients[10]*h_age + mod1$coefficients[12]*h_workingclass + mod1$coefficients[14]*h_income + mod1$coefficients[16]*h_education + mod1$coefficients[18]*h_tradeunion  + mod1$coefficients[20]*h_constant

e_betahat_women_cons <- exp(x_betahat_women_cons)
e_betahat_women_lab <- exp(x_betahat_women_lab)
e_betahat_women_libdem <- exp(x_betahat_women_libdem)

prob_cons_women <- e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
prob_lab_women <- e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
prob_libdem_women <- e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)

diff_cons<-prob_cons_women - prob_cons_men
diff_lab<-prob_lab_women - prob_lab_men
diff_libdem<-prob_libdem_women - prob_libdem_men

diff_percent_cons<-(diff_cons/prob_cons_men)*100
diff_percent_lab<-(diff_lab/prob_lab_men)*100
diff_percent_libdem<-(diff_libdem/prob_libdem_men)*100

#---- Remake plots to compare. Compare point estimates calculated	from simulation with point estimates from coefficients.	----

#---- Let's make some marginal effect plots - Conservatives	----

#---- Figure 10.4a ----
ggplot() +
  geom_line(aes(x = MV, y = diff_cons)) +
  geom_line(aes(x = MV, y = diff_hi_cons), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_cons), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/300), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*300, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Figure 10.4b	----
ggplot() +
  geom_line(aes(x = MV, y = diff_percent_cons)) +
  geom_line(aes(x = MV, y = percent_hi_cons), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_cons), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/1.5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*1.5, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Let's make some marginal effect plots - Labour ----

#---- Figure 10.4c	----
ggplot() +
  geom_line(aes(x = MV, y = diff_lab)) +
  geom_line(aes(x = MV, y = diff_hi_lab), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_lab), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/300), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*300, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Figure 10.4d	----
ggplot() +
  geom_line(aes(x = MV, y = diff_percent_lab)) +
  geom_line(aes(x = MV, y = percent_hi_lab), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_lab), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100*5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./5, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Let's make some marginal effect plots - Lib Dem	----

#---- Figure 10.4e	----
ggplot() +
  geom_line(aes(x = MV, y = diff_libdem)) +
  geom_line(aes(x = MV, y = diff_hi_libdem), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = diff_lo_libdem), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/50), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*50, name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Figure 10.4f ----
ggplot() +
  geom_line(aes(x = MV, y = diff_percent_libdem)) +
  geom_line(aes(x = MV, y = percent_hi_libdem), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = percent_lo_libdem), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100*8), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./8,  name="Percentage of Observations")
  ) +
  xlab("Conservative Government Intervention Incongruence") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

table(data$gov_intervention_distance[data$party_alternative==1])

describe(diff_cons)
describe(diff_percent_cons)
describe(diff_lab)
describe(diff_percent_lab)

diff_percent_lab[MV==0]
prob_lab_men[MV==0]
prob_lab_women[MV==0]

#---- Produce Figure 10.5 showing how the odds and percentage change in the odds of voting for the Conservatives rather than Labour	change for women as opposed to men when we vary the ideological	distance to the Conservative Party on the government intervention dimension 	----
odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector() 	
a <- 0
j <- 1
while(a <= 6.1){
  
  odds_lo[j] <- exp((mod1$coefficients[7] + mod1$coefficients[4]*a) - qnorm(0.975)*deltamethod(~ (x7 + x4*a), coef(mod1), vcov(mod1)))
  odds_hi[j] <- exp((mod1$coefficients[7] + mod1$coefficients[4]*a) + qnorm(0.975)*deltamethod(~ (x7 + x4*a), coef(mod1), vcov(mod1)))
  odds_hat[j] <- exp(mod1$coefficients[7] + mod1$coefficients[4]*a)
  a <- a + 0.1
  j <- j + 1
  
}

MV1 <- (n-1)/10
odds_percent <- (odds_hat-1)*100
odds_percent_lo <- (odds_lo-1)*100
odds_percent_hi <- (odds_hi-1)*100

table(data$gov_intervention_distance[data$party_alternative==1])

ggplot() +
  geom_line(aes(x = MV1, y = odds_hat)) +
  geom_line(aes(x = MV1, y = odds_hi), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV1, y = odds_lo), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100/5), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~.*5, name="Percentage of Observations")
  ) +
  xlab("Government Intervention Distance") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

ggplot() +
  geom_line(aes(x = MV1, y = odds_percent)) +
  geom_line(aes(x = MV1, y = odds_percent_hi), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV1, y = odds_percent_lo), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$gov_intervention_distance[data$party_alternative==1], y = (..count..)/sum(..count..)*100*20), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./20, name="Percentage of Observations")
  ) +
  xlab("Government Intervention Distance") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "dashed")

txtStop()
