# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "survival", "msm", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(survival) #for clogit
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter10_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter10_application")

txtStart("bes1992_collectdata_R.txt")

#---- Load in data ----
data <- read_dta('bes1992_small.dta')

names(data)
describe(data)

#---- Collect information related to Figure 10.4	----

#---- Pick values for baseline scenario	----
h_defense_distance1 <- 1
h_defense_distance2 <- 2
h_defense_distance3 <- 1

h_gov_intervention_distance2 <- 1
h_gov_intervention_distance3 <- 1

h_less_womensrights_distance1 <- 1
h_less_womensrights_distance2 <- 1
h_less_womensrights_distance3 <- 1

h_age <- 47
h_income <- 6
h_education <- 1
h_female <- 1
h_male <- 0
h_constant <- 1
h_workingclass <- 0
h_tradeunion <- 0


#---- Estimate model ----
mod1 <- clogit(choice ~ defense_distance + female_defense + gov_intervention_distance + 
         female_gov_intervention + less_womensrights_distance + female_less_womensrights +
         female1 + female3 + age1 + age3 + workingclass1 + workingclass3 + income_other1 +
         income_other3 + education1 + education3 + trade_union1 + trade_union3 + 
         alternative1 + alternative3 + strata(respondent_id), data)
mod1

set.seed(339487731)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))

prob_hat0_cons <- vector()
lo0_cons <- vector()
hi0_cons <- vector()
prob_hat0_lab <- vector()
lo0_lab <- vector()
hi0_lab <- vector()
prob_hat0_libdem <- vector()
lo0_libdem <- vector()
hi0_libdem <- vector()
prob_hat1_cons <- vector()
lo1_cons <- vector()
hi1_cons <- vector()
prob_hat1_lab <- vector()
lo1_lab <- vector()
hi1_lab <- vector()
prob_hat1_libdem <- vector()
lo1_libdem <- vector()
hi1_libdem <- vector()
diff_hat_cons <- vector()
diff_lo_cons <- vector()
diff_hi_cons <- vector()
diff_hat_lab <- vector()
diff_lo_lab <- vector()
diff_hi_lab <- vector()
diff_hat_libdem <- vector()
diff_lo_libdem <- vector()
diff_hi_libdem <- vector()
percent_hat_cons <- vector()
percent_lo_cons <- vector()
percent_hi_cons <- vector()
percent_hat_lab <- vector()
percent_lo_lab <- vector()
percent_hi_lab <- vector()
percent_hat_libdem <- vector()
percent_lo_libdem <- vector()
percent_hi_libdem <- vector()

a <- 0
j <- 1
while(a <= 6.1){
  
  #---- Men - baseline ----
  x_betahat_men_cons <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_male + 
  sim[, 3]*a + sim[, 4]*a*h_male +  sim[, 5]*h_less_womensrights_distance1 + 
  sim[, 6]*h_less_womensrights_distance1*h_male + sim[, 7]*h_male + sim[, 9]*h_age + 
  sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion  + sim[, 19]*h_constant
  
  x_betahat_men_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_male +
    sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_male +
    sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_male
  
  x_betahat_men_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_male +
    sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_male +
    sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_male +
    sim[, 8]*h_male + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income + sim[, 16]*h_education + 
    sim[, 18]*h_tradeunion  + sim[, 20]*h_constant
  
  e_betahat_men_cons <- exp(x_betahat_men_cons)
  e_betahat_men_lab <- exp(x_betahat_men_lab)
  e_betahat_men_libdem <- exp(x_betahat_men_libdem)
  
  prob_cons_men <- e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  prob_lab_men <- e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  prob_libdem_men <- e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem)
  
  probhat_cons_men <-mean(prob_cons_men)
  probhat_lab_men <-mean(prob_lab_men)
  probhat_libdem_men <-mean(prob_libdem_men)
  
  #---- Women - counterfactual ----
  x_betahat_women_cons <- sim[, 1]*h_defense_distance1 + sim[, 2]*h_defense_distance1*h_female +
  sim[, 3]*a + sim[, 4]*a*h_female +  sim[, 5]*h_less_womensrights_distance1 +
  sim[, 6]*h_less_womensrights_distance1*h_female + sim[, 7]*h_female + sim[, 9]*h_age +
  sim[, 11]*h_workingclass + sim[, 13]*h_income + sim[, 15]*h_education + sim[, 17]*h_tradeunion  + sim[, 19]*h_constant

  x_betahat_women_lab <- sim[, 1]*h_defense_distance2 + sim[, 2]*h_defense_distance2*h_female +
    sim[, 3]*h_gov_intervention_distance2 + sim[, 4]*h_gov_intervention_distance2*h_female +
    sim[, 5]*h_less_womensrights_distance2 + sim[, 6]*h_less_womensrights_distance2*h_female

  x_betahat_women_libdem <- sim[, 1]*h_defense_distance3 + sim[, 2]*h_defense_distance3*h_female +
    sim[, 3]*h_gov_intervention_distance3 + sim[, 4]*h_gov_intervention_distance3*h_female +
    sim[, 5]*h_less_womensrights_distance3 + sim[, 6]*h_less_womensrights_distance3*h_female +
    sim[, 8]*h_female + sim[, 10]*h_age + sim[, 12]*h_workingclass + sim[, 14]*h_income +
    sim[, 16]*h_education + sim[, 18]*h_tradeunion  + sim[, 20]*h_constant
 
  e_betahat_women_cons <- exp(x_betahat_women_cons)
  e_betahat_women_lab <- exp(x_betahat_women_lab)
  e_betahat_women_libdem <- exp(x_betahat_women_libdem)

  prob_cons_women <- e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
  prob_lab_women <- e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)
  prob_libdem_women <- e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem)

  probhat_cons_women <-mean(prob_cons_women)
  probhat_lab_women <-mean(prob_lab_women)
  probhat_libdem_women <-mean(prob_libdem_women)

  diff_cons<-prob_cons_women - prob_cons_men
  diff_lab<-prob_lab_women - prob_lab_men
  diff_libdem<-prob_libdem_women - prob_libdem_men

  diffhat_cons<-mean(diff_cons)
  diffhat_lab<-mean(diff_lab)
  diffhat_libdem<-mean(diff_libdem)

  diff_percent_cons<-(diff_cons/prob_cons_men)*100
  diff_percent_lab<-(diff_lab/prob_lab_men)*100
  diff_percent_libdem<-(diff_libdem/prob_libdem_men)*100

  diffhat_percent_cons<-mean(diff_percent_cons)
  diffhat_percent_lab<-mean(diff_percent_lab)
  diffhat_percent_libdem<-mean(diff_percent_libdem)
  
  lo0_cons[j] <- quantile(prob_cons_men, 0.025)
  hi0_cons[j] <- quantile(prob_cons_men, 0.975)
  
  lo0_lab[j] <- quantile(prob_lab_men, 0.025)
  hi0_lab[j] <- quantile(prob_lab_men, 0.975)
  
  lo0_libdem[j] <- quantile(prob_libdem_men, 0.025)
  hi0_libdem[j] <- quantile(prob_libdem_men, 0.975)
  
  lo1_cons[j] <- quantile(prob_cons_women, 0.025)
  hi1_cons[j] <- quantile(prob_cons_women, 0.975)
  
  lo1_lab[j] <- quantile(prob_lab_women, 0.025)
  hi1_lab[j] <- quantile(prob_lab_women, 0.975)
  
  lo1_libdem[j] <- quantile(prob_libdem_women, 0.025)
  hi1_libdem[j] <- quantile(prob_libdem_women, 0.975)
  
  diff_lo_cons[j] <- quantile(diff_cons, 0.025)
  diff_hi_cons[j] <- quantile(diff_cons, 0.975)
  
  diff_lo_lab[j] <- quantile(diff_lab, 0.025)
  diff_hi_lab[j] <- quantile(diff_lab, 0.975)
  
  diff_lo_libdem[j] <- quantile(diff_libdem, 0.025)
  diff_hi_libdem[j] <- quantile(diff_libdem, 0.975)
  
  percent_lo_cons[j] <- quantile(diff_percent_cons, 0.025)
  percent_hi_cons[j] <- quantile(diff_percent_cons, 0.975)
  
  percent_lo_lab[j] <- quantile(diff_percent_lab, 0.025)
  percent_hi_lab[j] <- quantile(diff_percent_lab, 0.975)
  
  percent_lo_libdem[j] <- quantile(diff_percent_libdem, 0.025)
  percent_hi_libdem[j] <- quantile(diff_percent_libdem, 0.975)
  
  prob_hat0_cons[j] <- probhat_cons_men
  prob_hat0_lab[j] <- probhat_lab_men
  prob_hat0_libdem[j] <- probhat_libdem_men
  prob_hat1_cons[j] <- probhat_cons_women
  prob_hat1_lab[j] <- probhat_lab_women
  prob_hat1_libdem[j] <- probhat_libdem_women
  diff_hat_cons[j] <- diffhat_cons
  diff_hat_lab[j] <- diffhat_lab
  diff_hat_libdem[j] <- diffhat_libdem
  percent_hat_cons[j] <- diffhat_percent_cons
  percent_hat_lab[j] <- diffhat_percent_lab
  percent_hat_libdem[j] <- diffhat_percent_libdem
  
  a <- a + 0.1
  j <- j + 1
  
}

n <- 1:62
MV <- (n-1)/10

#---- Grab information for the confidence intervals in Figure 10.4 ----
bes_female <- cbind(MV, diff_lo_cons, diff_hi_cons, percent_lo_cons, percent_hi_cons, diff_lo_lab, diff_hi_lab, percent_lo_lab, percent_hi_lab, diff_lo_libdem, diff_hi_libdem, percent_lo_libdem, percent_hi_libdem, diff_hat_cons, diff_hat_lab, diff_hat_libdem, percent_hat_cons, percent_hat_lab, percent_hat_libdem)
bes_female <- bes_female[1:61, ]
bes_female <- data.frame(bes_female) %>%
 dplyr::select(MV, diff_lo_cons, diff_hi_cons,  diff_lo_lab, diff_hi_lab, diff_lo_libdem, diff_hi_libdem, percent_lo_cons, percent_hi_cons, percent_lo_lab, percent_hi_lab, percent_lo_libdem, percent_hi_libdem, diff_hat_cons, diff_hat_lab, diff_hat_libdem, percent_hat_cons, percent_hat_lab, percent_hat_libdem) %>%
  filter(MV<=6)
write_csv(bes_female, 'bes_female_R.csv')


#---- Collect information related to Figure 10.5 ----
mod1

odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector() 	
a <- 0
j <- 1
while(a <= 6){
  
  odds_lo[j] <- exp((mod1$coefficients[7] + mod1$coefficients[4]*a) - qnorm(0.975)*deltamethod(~ (x7 + x4*a), coef(mod1), vcov(mod1)))
  odds_hi[j] <- exp((mod1$coefficients[7] + mod1$coefficients[4]*a) + qnorm(0.975)*deltamethod(~ (x7 + x4*a), coef(mod1), vcov(mod1)))
  odds_hat[j] <- exp(mod1$coefficients[7] + mod1$coefficients[4]*a)
  a <- a + 0.1
  j <- j + 1
  
}

n <- 1:61
MV <- (n-1)/10
odds_percent <- (odds_hat-1)*100
odds_percent_lo <- (odds_lo-1)*100
odds_percent_hi <- (odds_hi-1)*100

bes_female2 <- as.data.frame(cbind(MV, odds_hat, odds_lo, odds_hi, odds_percent, odds_percent_lo, odds_percent_hi))
write_csv(bes_female2, 'bes_female2_R.csv')

#---- Collect data on regions of statistical significance in Figures 10.3a and 10.3b	----

#---- Figure 10.3a -- womens rights are 0	----
p <- vector()
z <- vector()
def <- vector()
gov <- vector()

j <- 0
a <- 0
b <- 0
A <- seq(0, 6, 0.1)
for(a in A){
  for(b in A){
    def[j] <- a
    gov[j] <- b
    z[j] <- mod1$coefficients[7] + mod1$coefficients[2]*a +
      mod1$coefficients[4]*b + mod1$coefficients[6]*0
    se <- deltamethod(~x7 + x2*a + x4*b + x6*0, coef(mod1), vcov(mod1))
    zs <- (mod1$coefficients[7] + mod1$coefficients[2]*a +
      mod1$coefficients[4]*b + mod1$coefficients[6]*0)/se
    p[j] <- pnorm(zs, lower.tail = F)*2
    j <- j+1
  }
  }
sim_pred <- data.frame(cbind(def, gov, z, p))
sim_pred <- sim_pred[order(sim_pred$def, sim_pred$gov), ]
sim_pred <- filter(sim_pred, p<0.05)
write_csv(sim_pred, 'sim_pred_R.csv')

#---- Figure 10.3b -- womens rights are 1	----
p <- vector()
z <- vector()
def <- vector()
gov <- vector()

j <- 0
a <- 0
b <- 0
A <- seq(0, 6, 0.1)
for(a in A){
  for(b in A){
    def[j] <- a
    gov[j] <- b
    z[j] <- mod1$coefficients[7] + mod1$coefficients[2]*a +
      mod1$coefficients[4]*b + mod1$coefficients[6]*1
    se <- deltamethod(~x7 + x2*a + x4*b + x6*1, coef(mod1), vcov(mod1))
    zs <- (mod1$coefficients[7] + mod1$coefficients[2]*a +
             mod1$coefficients[4]*b + mod1$coefficients[6]*1)/se
    p[j] <- pnorm(zs, lower.tail = F)*2
    j <- j+1
  }
}
sim_pred2<- data.frame(cbind(def, gov, z, p))
sim_pred2 <- sim_pred2[order(sim_pred2$def, sim_pred2$gov), ]
sim_pred2 <- filter(sim_pred2, p<0.05)
write_csv(sim_pred2, 'sim_pred2_R.csv')


#---- Womens rights are 3.2 ----
p <- vector()
z <- vector()
def <- vector()
gov <- vector()

j <- 0
a <- 0
b <- 0
A <- seq(0, 6, 0.1)
for(a in A){
  for(b in A){
    def[j] <- a
    gov[j] <- b
    z[j] <- mod1$coefficients[7] + mod1$coefficients[2]*a +
      mod1$coefficients[4]*b + mod1$coefficients[6]*3.2
    se <- deltamethod(~x7 + x2*a + x4*b + x6*3.2, coef(mod1), vcov(mod1))
    zs <- (mod1$coefficients[7] + mod1$coefficients[2]*a +
             mod1$coefficients[4]*b + mod1$coefficients[6]*3.2)/se
    p[j] <- pnorm(zs, lower.tail = F)*2
    j <- j+1
  }
}
sim_pred3 <- data.frame(cbind(def, gov, z, p))
sim_pred3 <- sim_pred3[order(sim_pred3$def, sim_pred3$gov), ]
sim_pred3 <- filter(sim_pred3, p<0.05)

#---- Womens rights are 3.3 ----
p <- vector()
z <- vector()
def <- vector()
gov <- vector()

j <- 0
a <- 0
b <- 0
A <- seq(0, 6, 0.1)
for(a in A){
  for(b in A){
    def[j] <- a
    gov[j] <- b
    z[j] <- mod1$coefficients[7] + mod1$coefficients[2]*a +
      mod1$coefficients[4]*b + mod1$coefficients[6]*3.3
    se <- deltamethod(~x7 + x2*a + x4*b + x6*3.3, coef(mod1), vcov(mod1))
    zs <- (mod1$coefficients[7] + mod1$coefficients[2]*a +
             mod1$coefficients[4]*b + mod1$coefficients[6]*3.3)/se
    p[j] <- pnorm(zs, lower.tail = F)*2
    j <- j+1
  }
}
sim_pred4 <- data.frame(cbind(def, gov, z, p))
sim_pred4 <- sim_pred4[order(sim_pred4$def, sim_pred4$gov), ]
sim_pred4 <- filter(sim_pred4, p<0.05)

txtStop()