# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "survival", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(survival) #for clogit
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter10_exercise1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter10_exercise1")

txtStart("bes1992_exercise1_R.txt")

#---- Load in data ----
data <- read_dta('bes1992_small.dta')
names(data)
describe(data)

#---- Produce results shown in Table 10.7 in Chapter 10 ----
mod1 <- clogit(choice ~ gov_intervention_distance + female_gov_intervention + female1 +
         female3 + age1 + age3 +  workingclass1 + workingclass3 + income_other1 + 
         income_other3 + education1 + education3 + trade_union1 + trade_union3 +
         alternative1 + alternative3 + strata(respondent_id), data)
summary(mod1)

#---- Number of individuals ----
mod1$n/3

#---- Marginal effects on utility ----

# Men
mod1$coefficients[1]

# Women
mod1$coefficients[1] + mod1$coefficients[2]*1

# Modifying the effect of being female
mod1$coefficients[2]

h_gov_intervention_distance1  <- 2
h_gov_intervention_distance2 <- 1
h_gov_intervention_distance3 <- 1

h_age <- 30
h_income <- 6
h_education <- 1
h_female <- 1
h_male <- 0
h_constant <- 1
h_workingclass <- 0
h_tradeunion <- 0

#---- Direct marginal effect of government intervention on theprobability of voting conservative - men ----			
# The numbers will be slightly off from those in the book because there's some rounding in the results presented in the book


x_betahat_men_cons <- mod1$coefficients[1]*h_gov_intervention_distance1 + 
  mod1$coefficients[2]*mod1$coefficients[1]*h_male + mod1$coefficients[3]*h_male + 
  mod1$coefficients[5]*h_age + mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
  mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion  + mod1$coefficients[15]*h_constant; x_betahat_men_cons

x_betahat_men_lab <- mod1$coefficients[1]*h_gov_intervention_distance2 +
  mod1$coefficients[2]*h_gov_intervention_distance2*h_male; x_betahat_men_lab

x_betahat_men_libdem <- mod1$coefficients[1]*h_gov_intervention_distance3 +
  mod1$coefficients[2]*h_gov_intervention_distance3*h_male + mod1$coefficients[4]*h_male + 
  mod1$coefficients[6]*h_age + mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income + 
  mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion  + 
  mod1$coefficients[16]*h_constant; x_betahat_men_libdem

e_betahat_men_cons <- exp(mod1$coefficients[1]*h_gov_intervention_distance1 + 
                            mod1$coefficients[2]*h_gov_intervention_distance1*h_male + 
                            mod1$coefficients[3]*h_male + mod1$coefficients[5]*h_age + 
                            mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
                            mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion +
                            mod1$coefficients[15]*h_constant); e_betahat_men_cons

e_betahat_men_lab <- exp(mod1$coefficients[1]*h_gov_intervention_distance2 + 
                          mod1$coefficients[2]*h_gov_intervention_distance2*h_male); e_betahat_men_lab

e_betahat_men_libdem <- exp(mod1$coefficients[1]*h_gov_intervention_distance3 +
                              mod1$coefficients[2]*h_gov_intervention_distance3*h_male +
                              mod1$coefficients[4]*h_male + mod1$coefficients[6]*h_age +
                              mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
                              mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion  + 
                              mod1$coefficients[16]*h_constant); e_betahat_men_libdem

prob_men <- e_betahat_men_cons/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_men

marginal_men <- prob_men*(1-prob_men)*(mod1$coefficients[1] + mod1$coefficients[2]*h_male); marginal_men

#---- Direct marginal effect of government intervention on the probability of voting conservative - women ----
x_betahat_women_cons <- mod1$coefficients[1]*h_gov_intervention_distance1 + 
  mod1$coefficients[2]*h_gov_intervention_distance1*h_female + mod1$coefficients[3]*h_female +
  mod1$coefficients[5]*h_age + mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
  mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion  + 
  mod1$coefficients[15]*h_constant; x_betahat_women_cons

x_betahat_women_lab <- mod1$coefficients[1]*h_gov_intervention_distance2 +
  mod1$coefficients[2]*h_gov_intervention_distance2*h_female; x_betahat_women_lab

x_betahat_women_libdem <- mod1$coefficients[1]*h_gov_intervention_distance3 +
  mod1$coefficients[2]*h_gov_intervention_distance3*h_female + mod1$coefficients[4]*h_female +
  mod1$coefficients[6]*h_age + mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
  mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion  + 
  mod1$coefficients[16]*h_constant; x_betahat_women_libdem

e_betahat_women_cons <- exp(mod1$coefficients[1]*h_gov_intervention_distance1 +
                               mod1$coefficients[2]*h_gov_intervention_distance1*h_female + 
                               mod1$coefficients[3]*h_female + mod1$coefficients[5]*h_age +
                               mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
                               mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion +
                               mod1$coefficients[15]*h_constant); e_betahat_women_cons

e_betahat_women_lab <- exp(mod1$coefficients[1]*h_gov_intervention_distance2 +
                             mod1$coefficients[2]*h_gov_intervention_distance2*h_female); e_betahat_women_lab


e_betahat_women_libdem <- exp(mod1$coefficients[1]*h_gov_intervention_distance3 + 
                                mod1$coefficients[2]*h_gov_intervention_distance3*h_female +
                                mod1$coefficients[4]*h_female + mod1$coefficients[6]*h_age +
                                mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
                                mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion  +
                                mod1$coefficients[16]*h_constant); e_betahat_women_libdem

prob_women  <-  e_betahat_women_cons/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_women

marginal_women <- prob_women*(1-prob_women)*(mod1$coefficients[1]+mod1$coefficients[2]*h_female); marginal_women

#---- Modifying effect of being female on direct marginal effect ---- 
marginal_women - marginal_men

#---- Cross marginal effects on probability - labour - men ----

prob_men_lab <- e_betahat_men_lab/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_men_lab

crossmarginal_men <- -prob_men*prob_men_lab*(mod1$coefficients[1]+mod1$coefficients[2]*h_male); crossmarginal_men

#---- Cross marginal effects on probability - labour - women ----		
prob_women_lab <- e_betahat_women_lab/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_women_lab

crossmarginal_women <- -prob_women*prob_women_lab*(mod1$coefficients[1]+mod1$coefficients[2]*h_female); crossmarginal_women

#---- Cross marginal effects on probability - libdem - men ----
prob_men_libdem <- e_betahat_men_libdem/(e_betahat_men_cons+e_betahat_men_lab+e_betahat_men_libdem); prob_men_libdem

crossmarginal_men_libdem <-  -prob_men*prob_men_libdem*(mod1$coefficients[1]+mod1$coefficients[2]*h_male); crossmarginal_men_libdem

#----	Cross marginal effects on probability - libdem - women ----
prob_women_libdem <- e_betahat_women_libdem/(e_betahat_women_cons+e_betahat_women_lab+e_betahat_women_libdem); prob_women_libdem;

crossmarginal_women_libdem <- -prob_women*prob_women_libdem*(mod1$coefficients[1]+mod1$coefficients[2]*h_female); crossmarginal_women_libdem

#---- Direct marginal effects and cross-marginal effects should sum	to 0 ----  
marginal_men + crossmarginal_men + crossmarginal_men_libdem
marginal_women + crossmarginal_women + crossmarginal_women_libdem

#----	Men: Discrete change - counterfactual
# Increase gov_intervention_distance by 2 units for conservatives

h_gov_intervention_distance1c <- 4

x_betahat_men_cons2 <-mod1$coefficients[1]*h_gov_intervention_distance1c + 
  mod1$coefficients[2]*h_gov_intervention_distance1c*h_male + mod1$coefficients[3]*h_male +
  mod1$coefficients[5]*h_age + mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
  mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion +
  mod1$coefficients[15]*h_constant; x_betahat_men_cons2

x_betahat_men_lab2 <-  mod1$coefficients[1]*h_gov_intervention_distance2 + 
  mod1$coefficients[2]*h_gov_intervention_distance2*h_male; x_betahat_men_lab2

x_betahat_men_libdem2 <-mod1$coefficients[1]*h_gov_intervention_distance3 + 
  mod1$coefficients[2]*h_gov_intervention_distance3*h_male + mod1$coefficients[4]*h_male +
  mod1$coefficients[6]*h_age + mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
  mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion +
  mod1$coefficients[16]*h_constant; x_betahat_men_libdem2

e_betahat_men_cons2 <- exp(mod1$coefficients[1]*h_gov_intervention_distance1c +
                             mod1$coefficients[2]*h_gov_intervention_distance1c*h_male +
                             mod1$coefficients[3]*h_male + mod1$coefficients[5]*h_age + 
                             mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
                             mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion +
                             mod1$coefficients[15]*h_constant); e_betahat_men_cons2

e_betahat_men_lab2 <- exp( mod1$coefficients[1]*h_gov_intervention_distance2 +
                             mod1$coefficients[2]*h_gov_intervention_distance2*h_male); e_betahat_men_lab2

e_betahat_men_libdem2 <- exp(mod1$coefficients[1]*h_gov_intervention_distance3 + 
                               mod1$coefficients[2]*h_gov_intervention_distance3*h_male +
                               mod1$coefficients[4]*h_male + mod1$coefficients[6]*h_age +
                               mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
                               mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion  +
                               mod1$coefficients[16]*h_constant); e_betahat_men_libdem2

prob_men2 <- e_betahat_men_cons2/(e_betahat_men_cons2+e_betahat_men_lab2+e_betahat_men_libdem2); prob_men2

prob_men2-prob_men

#---- Women: Discrete change - counterfactual ----
# Increase gov_intervention_distance by 2 units for conservatives

x_betahat_women_cons2 <- mod1$coefficients[1]*h_gov_intervention_distance1c +
  mod1$coefficients[2]*h_gov_intervention_distance1c*h_female +
  mod1$coefficients[3]*h_female + mod1$coefficients[5]*h_age +
  mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
  mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion +
  mod1$coefficients[15]*h_constant; x_betahat_women_cons2

x_betahat_women_lab2 <- mod1$coefficients[1]*h_gov_intervention_distance2 + 
  mod1$coefficients[2]*h_gov_intervention_distance2*h_female; x_betahat_women_lab2

x_betahat_women_libdem2 <- mod1$coefficients[1]*h_gov_intervention_distance3 +
  mod1$coefficients[2]*h_gov_intervention_distance3*h_female +
  mod1$coefficients[4]*h_female + mod1$coefficients[6]*h_age + 
  mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
  mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion + 
  mod1$coefficients[16]*h_constant; x_betahat_women_libdem2

e_betahat_women_cons2 <- exp(mod1$coefficients[1]*h_gov_intervention_distance1c +
                              mod1$coefficients[2]*h_gov_intervention_distance1c*h_female +
                              mod1$coefficients[3]*h_female + mod1$coefficients[5]*h_age +
                              mod1$coefficients[7]*h_workingclass + mod1$coefficients[9]*h_income +
                              mod1$coefficients[11]*h_education + mod1$coefficients[13]*h_tradeunion  + 
                              mod1$coefficients[15]*h_constant); e_betahat_women_cons2

e_betahat_women_lab2 <- exp(mod1$coefficients[1]*h_gov_intervention_distance2 +
                              mod1$coefficients[2]*h_gov_intervention_distance2*h_female); e_betahat_women_lab2

e_betahat_women_libdem2 <- exp(mod1$coefficients[1]*h_gov_intervention_distance3 +
                                 mod1$coefficients[2]*h_gov_intervention_distance3*h_female +
                                 mod1$coefficients[4]*h_female + mod1$coefficients[6]*h_age +
                                 mod1$coefficients[8]*h_workingclass + mod1$coefficients[10]*h_income +
                                 mod1$coefficients[12]*h_education + mod1$coefficients[14]*h_tradeunion + 
                                 mod1$coefficients[16]*h_constant); e_betahat_women_libdem2

prob_women2 <- e_betahat_women_cons2/(e_betahat_women_cons2+e_betahat_women_lab2+e_betahat_women_libdem2); prob_women2

prob_women2-prob_women

(prob_women2-prob_women)-(prob_men2-prob_men)

#---- Odds ratio - men ---- 
(exp(mod1$coefficients[1]*2)-1)*100

#----	Odds ratio - women ----
(exp((mod1$coefficients[1]+mod1$coefficients[2])*2)-1)*100

#---- Modifying effect of being female ----
((exp((mod1$coefficients[1]+mod1$coefficients[2])*2)-1)*100)-((exp(mod1$coefficients[1]*2)-1)*100)
(((exp((mod1$coefficients[1]+mod1$coefficients[2])*2)-1)*100)-((exp(mod1$coefficients[1]*2)-1)*100))/((exp(mod1$coefficients[1]*2)-1)*100)*100

txtStop()