# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "regclass", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(regclass) #for VIF
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter3_exercise2")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter3_exercise2")

txtStart("parties_R.txt")

#---- Load in data ----
data <- read_dta('coxappend.dta')

#---- Summary Statistcs ----
describe(data)

#----	Variable Names ----													                            
#	enpv = Number of Parties									                        	
#	eneth = Social Divisions										                      
#	lnml = Electoral Permissiveness									                    
#	lmleneth = Social Divisons x Electoral Permissiveness			         
describe(data$eneth)
describe(data$lnml)


#----	Results for uncentered model in Table 3.3 (second column) ----			        
data_uncentered <- subset(data, drop == 0)
uncentered_model <- lm(enpv ~ eneth + lnml + lmleneth, data = data_uncentered)
summary(uncentered_model)

VIF(uncentered_model)
mean(c(VIF(uncentered_model)[1], VIF(uncentered_model)[2], VIF(uncentered_model)[3]))
1/(c(VIF(uncentered_model)[1], VIF(uncentered_model)[2], VIF(uncentered_model)[3]))

#---- Mean center variables in order to produce results in Table 3.3 ----
data <- data %>%
  mutate(centered_eneth = eneth - mean(eneth),
         centered_lnml = lnml - mean(lnml),
         centered_eneth_lnml = centered_eneth*centered_lnml)

#---- Results for mean-centered model in Table 3.3 (first column)	----
data_centered <- subset(data, drop == 0)
cenetered_model <- lm(enpv ~ centered_eneth + centered_lnml + centered_eneth_lnml, data = data_centered)
summary(cenetered_model)

VIF(cenetered_model)
mean(c(VIF(cenetered_model)[1], VIF(cenetered_model)[2], VIF(cenetered_model)[3]))
1/(c(VIF(cenetered_model)[1], VIF(cenetered_model)[2], VIF(cenetered_model)[3]))

#---- Calculate the marginal effect of Social Divisions when	Electoral Permissiveness is 0	----
summary(glht(cenetered_model, linfct = c("centered_eneth - centered_eneth_lnml*1.53 = 0")))
confint(glht(cenetered_model, linfct = c("centered_eneth - centered_eneth_lnml*1.53 = 0")))

#---- Calculate the marginal effect of Electoral Permissiveness when	Social Divisions is 0 ----
summary(glht(cenetered_model, linfct = c("centered_lnml - centered_eneth_lnml*1.57 = 0")))
confint(glht(cenetered_model, linfct = c("centered_lnml - centered_eneth_lnml*1.57 = 0")))

#---- Calculate the constant from the uncentered model ----
summary(glht(cenetered_model, linfct = c("(Intercept) - centered_eneth*1.57 - centered_lnml*1.53 +
                                         centered_eneth_lnml*1.57*1.53 = 0")))
confint(glht(cenetered_model, linfct = c("(Intercept) - centered_eneth*1.57 - centered_lnml*1.53 +
                                         centered_eneth_lnml*1.57*1.53 = 0")))
txtStop()