# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "expss", "psych", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(expss) #for labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter3_exercise4")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter3_exercise4")

txtStart("race_R.txt")

#---- Load in data ----
data <- read_dta('rep_banks_2012a.dta')

#---- Summary Statistics ---- 
describe(data)

#--- Label and rename variables to match the discussion in Question 4 in the Exercises at the end of Chapter 3	----
data <- data %>%
  mutate(
    resentment_anger=anger*racresent1,
    resentment_calm = racresent1*(1-anger),
  ) %>%
  rename(
    symbolic_resentment = racresent1,
    racepolicy = racpolicy
  ) %>%
  apply_labels(
    anger = "anger",
    symbolic_resentment = "symbolic resentment",
    resentment_anger = "symbolic resentment -- angry",
    angerres1 = "anger * symbolic resentment",
    resentment_calm = "symbolic resentment -- calm"
  )

# The following analyses have no control variables

#---- Produce results from the standard interaction model shown in Table 3.5 in Chapter 3 and Table S.3 in the Solutions chapter. ----
summary(lm(racepolicy ~ symbolic_resentment + anger + resentment_anger, data))

#---- Produce results from the alternative interaction model shown in Table S.3 in the Solutions chapter. ----
summary(lm(racepolicy ~ anger + resentment_calm + resentment_anger, data))

#---- Produce results from the split sample strategy shown in Table S.3 in the Solutions chapter.----
data_noanger <- subset(data, anger == 0)
data_anger <- subset(data, anger == 1)

summary(lm(racepolicy ~ symbolic_resentment, data_noanger))
summary(lm(racepolicy ~ symbolic_resentment, data_anger))

# The following analyses include control variables	

#---- Standard interaction model ----
summary(lm(racepolicy ~ symbolic_resentment + anger + resentment_anger + fearres1 +
             fear + disgust + disgusres1 + ideology + education + income1 + age + 
             south + openissuejo1, data))

#---- Alternative interaction model ----
summary(lm(racepolicy ~ anger + resentment_calm + resentment_anger + fearres1 +
             fear + disgust + disgusres1 + ideology + education + income1 + age +
             south + openissuejo1, data))

#---- Split sample strategy ----
summary(lm(racepolicy ~ symbolic_resentment + fearres1 + fear + disgust + disgusres1 +
             ideology + education + income1 + age + south + openissuejo1, data_noanger))

summary(lm(racepolicy ~ symbolic_resentment + fearres1 + fear + disgust + disgusres1 +
             ideology + education + income1 + age + south + openissuejo1, data_anger))
txtStop()
