# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter3_exercise5")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter3_exercise5")

txtStart("race_gender_R.txt")

#---- Load in data ----
data <- read_dta('anes2016_small.dta')

#---- Variable description and summary statistics ----
names(data)
describe(data)

#----- Drop respondents who are not white or black ----
data <- filter(data, white == 1 | black == 1)

#---- Generate interaction term for gender and race ----
data <- data %>%
  mutate(
    female_black = female*black,
    female_white = female*white,
    male_black = male*black,
    male_white = male*white
  )

data <- data %>%
  dplyr::select(respondent_id, female, male, black, white, female_black, female_white, male_black, male_white, everything()) 

#---- Produce results from the standard interaction model shown in Table S.4 in the Solutions chapter. ----
mod1 <- lm(like_republican ~ female + black + female_black + age, data)
summary(mod1)

#---- Produce results from alternative interaction model I shown in Table 3.6 in Chapter 3 and Table S.4 in the Solutions chapter. ----
# This is the model where White men are the reference category.
mod2 <- lm(like_republican ~ female_white + male_black + female_black + age, data)
summary(mod2)

#---- Calculate the interaction effect of gender and race ----
summary(glht(mod2, linfct = c("female_black - female_white - male_black = 0")))
confint(glht(mod2, linfct = c("female_black - female_white - male_black = 0")))

#---- Produce results from alternative interaction model II shown in Table S.4 in the Solutions chapter. ----	
# This is the model where Black women are the reference category.
mod3 <- lm(like_republican  ~ female_white +  male_black +  male_white + age, data)
summary(mod3)
vcov(mod3)

txtStop()