# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter4_exercise1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter4_exercise1")

txtStart("race2_R.txt")

#---- Load in data ----
data <- read_dta('rep_banks_2012a.dta')

#---- Summary Statistics ---- 
describe(data)

#--- Label and rename variables to match the discussion in Question 4 in the Exercises at the end of Chapter 3	----
data <- data %>%
  mutate(
    resentment_anger=anger*racresent1,
    resentment_calm = racresent1*(1-anger),
  ) %>%
  rename(
    symbolic_resentment = racresent1,
    racepolicy = racpolicy
  ) %>%
  apply_labels(
    anger = "anger",
    symbolic_resentment = "symbolic resentment",
    resentment_anger = "symbolic resentment -- angry",
    angerres1 = "anger * symbolic resentment",
    resentment_calm = "symbolic resentment -- calm"
  )

#---- Produce results from the standard interaction model shown in Table 4.1 in Chapter 4 and Table S.5 in the Solutions chapter. ----
mod1 <- lm(racepolicy ~ symbolic_resentment + anger + resentment_anger, data)
summary(mod1)

#---- Obtain variance-covariance matrix of estimated coefficients ----
vcov(mod1)

#---- Obtain degrees of freedom ----
df <- summary(mod1)$df[2]; df

#---- Obtain critical t-value for this degrees of freedom assuming an alpha level of 0.05	----
qt(0.025, df, lower.tail = FALSE)

#---- Calculate marginal effect of Symbolic Racism when Anger = 0 ----
summary(glht(mod1, linfct = c("symbolic_resentment = 0")))
confint(glht(mod1, linfct = c("symbolic_resentment = 0")))

#---- Calculate marginal effect of Symbolic Racism when Anger = 1	----
summary(glht(mod1, linfct = c("symbolic_resentment + resentment_anger = 0")))
confint(glht(mod1, linfct = c("symbolic_resentment + resentment_anger = 0")))

#---- Calculate the effect of Anger when Symbolic Racism = 0 ----
summary(glht(mod1, linfct = c("anger = 0")))
confint(glht(mod1, linfct = c("anger = 0")))

#---- Calculate the effect of Anger when Symbolic Racism = 0.5 ----
summary(glht(mod1, linfct = c("anger + resentment_anger * 0.5 = 0")))
confint(glht(mod1, linfct = c("anger + resentment_anger * 0.5 = 0")))

#---- Calculate the effect of Anger when Symbolic Racism = 1 ----
summary(glht(mod1, linfct = c("anger + resentment_anger * 1 = 0")))
confint(glht(mod1, linfct = c("anger + resentment_anger * 1 = 0")))

#---- Calculate the predicted value of Oppose Race Policies when Symbolic Racism = 0.5 and Anger = 0 ----
summary(glht(mod1, linfct = c("(Intercept) + symbolic_resentment * 0.5 = 0")))
confint(glht(mod1, linfct = c("(Intercept) + symbolic_resentment * 0.5 = 0")))

#---- Calculate the predicted value of Oppose Race Policies when Symbolic Racism = 0.5 and Anger = 1 ----
summary(glht(mod1, linfct = c("(Intercept) + symbolic_resentment * 0.5 + anger + resentment_anger * 0.5 = 0")))
confint(glht(mod1, linfct = c("(Intercept) + symbolic_resentment * 0.5 + anger + resentment_anger * 0.5 = 0")))

#---- Calculate the difference in the predicted value of Oppose Race Policies
# when Symbolic Racism = 0.5 and we change Anger from 0 to 1. 
# This is the effect of Anger when Symbolic Racism = 0.5 
summary(glht(mod1, linfct = c(" anger + resentment_anger * 0.5 = 0")))
confint(glht(mod1, linfct = c(" anger + resentment_anger * 0.5 = 0")))

txtStop()