# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "regclass", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(regclass) #for VIF
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter5_exercise1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter5_exercise1")

txtStart("exercise1_R.txt")

#---- Load in data ----
data <- read_dta('final.dta')

#---- Variable description ----
names(data)

#---- Generate interaction term ----
data$leaders_labor <- data$women_leaders * data$labor

#---- Standard interaction model - uncentered ----
mod1 <- lm(womens_representation ~ women_leaders + labor + leaders_labor + effectivequota + polity, data)
summary(mod1)

#---- Produce a figure like Figure 5.8a in R showing the marginal	effect of demand across the observed range of values for supply. ----
# Note that the figures in the book were created using pgfplots not R 
summary(mod1)
describe(data$labor)
describe(data$women_leaders)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

vcov(mod1)

n <- 1:11167
MV <- (n-1)/100
conbx <- b1+b3*MV
consx <- sqrt(varb1+varb3*(MV^2)+2*MV*covb1b3) 

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Limit to range of observed data. ----
MV <- MV[864:11103]
conbx <- conbx[864:11103]
lowerx <- lowerx[864:11103]
upperx <- upperx[864:11103]

#---- Draw the plot. ----
# The histogram differs slightly from the one shown in Figure 5.8a because the 
# bar widths and locations are not identical.
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  xlim(0, 115) +
  geom_histogram(aes(x = data$labor, y = (..count..)/sum(..count..)*100/10), bins = 55, alpha = 0.1) +
  theme_bw() + 
  ylim(-1,1) +
  scale_y_continuous(
    name = "Marginal Effect of Demand",
    sec.axis = sec_axis(~.*10, name="Percentage of Observations")
  ) +
  xlab("Supply (Ratio of Female to Male Labor Force Participation)") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Calculate the value of supply at which the confidence interval for the marginal effect of demand is narrowest.	----
# This differs from the answer in the book only because of the rounding that  
# is used in the book when presenting covariances and variances.
covb1b3
varb3
-covb1b3/varb3
-(-0.000207/0.000003)

#---- We can also check this numerically to 2 decimal places. ----
gap <- upperx - lowerx
describe(gap)
min_gap <- describe(gap)$min; min_gap
MV[gap == min_gap]

describe(data$labor)

#---- Produce a figure like Figure 5.8b in R showing the marginal	effect of supply across the observed range of values for demand. ----
# Note that the figures in the book were created using pgfplots not R
rm(MV, conbx, consx, lowerx, upperx)
summary(mod1)
describe(data$labor)
describe(data$women_leaders)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals ----
b1 <- mod1$coefficients[2]; b1
b2 <- mod1$coefficients[3]; b2
b3 <- mod1$coefficients[4]; b3
varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
covb1b3 <- vcov(mod1)[2, 4]; covb1b3
covb3b2 <- vcov(mod1)[4, 3]; covb3b2

vcov(mod1)

n <- 1:9399
MV <- (n-1)/100
conbx <- b2+b3*MV
consx <- sqrt(varb2+varb3*(MV^2)+2*MV*covb3b2)

#---- Obtain degrees of freedom and critical t-value for creating	confidence intervals ----
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Limit to range of observed data. ----
MV <- MV[799:9184]
conbx <- conbx[799:9184]
lowerx <- lowerx[799:9184]
upperx <- upperx[799:9184]

#---- Draw the plot. ----
# The histogram differs slightly from the one shown in Figure 5.8b because the bar
# widths and locations are not identical.	
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  xlim(0, 115) +
  geom_histogram(aes(x = data$women_leaders, y = (..count..)/sum(..count..)*100/10), bins = 21, alpha = 0.1) +
  theme_bw() + 
  ylim(-1,1) +
  scale_y_continuous(
    name = "Marginal Effect of Supply",
    sec.axis = sec_axis(~.*10, name="Percentage of Observations")
  ) +
  xlab("Demand") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

#---- Calculate the value of demand at which the confidence interval for the marginal effect of supply is narrowest.	----
# This differs from the answer in the book only because of the rounding that  
# is used in the book when presenting covariances and variances.
covb3b2
varb3
-covb3b2/varb3
-(-0.000107/0.000003)

#---- We can also check this numerically to 2 decimal places. ----
gap <- upperx - lowerx
describe(gap)
min_gap <- describe(gap)$min; min_gap
MV[gap == min_gap]

describe(data$women_leaders)

#---- Calculate the value of demand at which the confidence interval for the marginal effect of supply cuts the zero line using the information in Appendix D. ----
# The values don't perfectly match the answers in the book. 
# This is because of the rounding that is used in the book when presenting covariances and variances. 

# lower bound
(-(2*b2*b3-2*t*t*covb3b2)+sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3))

#---- We can also check this numerically by looking at the value of	MV where lowerx and upperx switch signs in the data editor.	----

# upper bound
(-(2*b2*b3-2*t*t*covb3b2)-sqrt((2*b2*b3-2*t*t*covb3b2)*(2*b2*b3-2*t*t*covb3b2)-4*(b3*b3-t*t*varb3)*(b2*b2-t*t*varb2)))/(2*(b3*b3-t*t*varb3))

txtStop()