# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter6_application1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter6_application1")

txtStart("anes2016_feminism_analysis_R.txt")

#---- Load in data ----
data <- read_dta('anes2016_small.dta')

#---- Variable description ----
names(data)

#---- Summary Statistics ---- 
describe(data)
describe(data$thermometer_feminist)
describe(data$age[data$male==1])
describe(data$age[data$female==1])

#---- Create dummy for college education, BA and up	----
data$college_educated <- ifelse(data$education > 12, 1, 0)
table(data$college_educated)

#---- Create interaction terms ----
data <- data %>%
  mutate(female_educated = female*college_educated,
         female_age=female*age)

#----	Produce results shown in Table 6.1 in Chapter 6	----
mod1 <- lm(thermometer_feminist ~ female + college_educated + age + 
             female_educated + female_age + black + asian + native_american +
             hispanic + race_other + religion_important + left_right, data)
summary(mod1)
#----	Get precise p-value for coefficient on female_educated	----
summary(mod1)$coefficients[, c(1,4)]
vcov(mod1)

#---- Produce a marginal effect plot similar to the one shown in	Figure 6.9a. ----
# The marginal effect of being female across the range of values for age for 
# the non-college educated. 	Note that the figures in the book were created using
# pgfplots, not R	

summary(mod1)

#---- Obtain the necessary coefficients, variances, and covariances to calculate effects and confidence intervals	----		
b1 <- summary(mod1)$coefficients[2, 1]; b1
b2 <- summary(mod1)$coefficients[3, 1]; b2
b3 <- summary(mod1)$coefficients[4, 1]; b3
b4 <- summary(mod1)$coefficients[5, 1]; b4
b5 <- summary(mod1)$coefficients[6, 1]; b5

varb1 <- vcov(mod1)[2, 2]; varb1
varb2 <- vcov(mod1)[3, 3]; varb2
varb3 <- vcov(mod1)[4, 4]; varb3
varb4 <- vcov(mod1)[5, 5]; varb4
varb5 <- vcov(mod1)[6, 6]; varb5

covb1b4 <- vcov(mod1)[2,5]; covb1b4
covb1b5 <- vcov(mod1)[2,6]; covb1b5
covb4b5 <- vcov(mod1)[5,6]; covb4b5


n <- 1:721
MV <- ((n-1)/10)+18
conbx <- b1+b4*0+b5*MV
consx <- sqrt(varb1+varb4*(0^2)+varb5*(MV^2)+2*0*covb1b4+2*MV*covb1b5+2*0*MV*covb4b5) 
df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t
lowerx <- conbx - (t*consx)
upperx <- conbx + (t*consx)

#---- Produce the plot in Figure 6.9a. The histogram will be a little	different due to different bar widths and locations. ----
data_nocollege <- filter(data, college_educated == 0)
ggplot() +
  geom_line(aes(x = MV, y = conbx)) +
  geom_line(aes(x = MV, y = upperx), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data_nocollege$age, y = (..count..)/sum(..count..)*100*5), bins = 70, alpha = 0.1) +
  theme_bw() + 
  ylim(-20,20) +
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./5, name="Percentage of Observations")
  ) +
  xlab("Age") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")

#----	Percentage of observations that fall into the different regions	in the plot using the cutpoints identified in the data editor. ----
describe(data$respondent_id[data$college_educated == 0 & !is.na(data$age)])
total <- describe(data$respondent_id[data$college_educated == 0& !is.na(data$age)])$n; total

describe(data$respondent_id[data$age < 63.2 & data$college_educated == 0])
subtotal1 <- describe(data$respondent_id[data$age < 63.2 & data$college_educated == 0])$n; subtotal1
(subtotal1/total)*100

describe(data$respondent_id[data$age > 63.2 & data$age < 78.5 & data$college_educated == 0])
subtotal2 <- describe(data$respondent_id[data$age > 63.2 & data$age < 78.5 & data$college_educated == 0])$n; subtotal2
(subtotal2/total)*100

describe(data$respondent_id[data$age > 78.4 & data$college_educated == 0])
subtotal3 <- describe(data$respondent_id[data$age > 78.4 & data$college_educated == 0])$n; subtotal3
(subtotal3/total)*100


#---- Produce a marginal effect plot similar to the one shown in  Figure 6.9b. The marginal effect of being female across the range of values for age for the college educated. ----	
# Note that the figures in the book were created using pgfplots, not R
conbx2 <- b1+b4*1+b5*MV
consx2 <- sqrt(varb1+varb4*(1^2)+varb5*(MV^2)+2*1*covb1b4+2*MV*covb1b5+2*1*MV*covb4b5)
lowerx2 <- conbx2 - (t*consx2)
upperx2 <- conbx2 + (t*consx2)

#----	Produce the plot in Figure 6.9b. The histogram will be a little	different due to different bar widths and locations. ----
data_college <- filter(data, college_educated == 1)
ggplot() +
  geom_line(aes(x = MV, y = conbx2)) +
  geom_line(aes(x = MV, y = upperx2), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = lowerx2), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data_college$age, y = (..count..)/sum(..count..)*100*5), bins = 70, alpha = 0.1) +
  theme_bw() + 
  ylim(-20,20) +
  scale_y_continuous(
    name = "Effect of being Female",
    sec.axis = sec_axis(~./5, name="Percentage of Observations")
  ) +
  xlab("Age") +
  theme(axis.title.y.right = element_text(color = "gray")) +
  geom_hline(yintercept = 0, lty = "dashed")


describe(data$respondent_id[data$college_educated == 1 & !is.na(data$age)])
total2 <- describe(data$respondent_id[data$college_educated == 1 & !is.na(data$age)])$n; total2

describe(data$respondent_id[data$age < 77.7 & data$college_educated == 1])
subtotal4 <- describe(data$respondent_id[data$age < 77.7 & data$college_educated == 1])$n; subtotal4
(subtotal4/total2)*100

describe(data$respondent_id[data$age > 77.6 & data$college_educated == 1 & !is.na(data$age)])
subtotal5 <- describe(data$respondent_id[data$age > 77.6 & data$college_educated == 1 & !is.na(data$age)])$n; subtotal5
(subtotal5/total2)*100

#---- Percentage of respondents where effect of being female is	positive. ----
describe(data$respondent_id[!is.na(data$college_educated) & !is.na(data$age)])
total3 <- describe(data$respondent_id[!is.na(data$college_educated) & !is.na(data$age)])$n; total3

((subtotal1+subtotal2+subtotal4+subtotal5)/total3)*100

#----	Percentage of respondents where effect of being female is	positive and statistically significant.	----
((subtotal1+subtotal4)/total3)*100

#---- Substantive significance -- effect of being female rather than male for a 25 year old college graduate. ----  
summary(glht(mod1, linfct = c("female + female_educated + female_age*25 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_educated + female_age*25 = 0"))))

describe(data$thermometer_feminist[data$male == 1 & data$age>19 & data$age<30 & data$college_educated==1])
mean20 <- describe(data$thermometer_feminist[data$male == 1 & data$age>19 & data$age<30 & data$college_educated==1])$mean; mean20

((mod1$coefficients[2] + mod1$coefficients[5] + mod1$coefficients[6]*25)/mean20)*100

#---- Substantive significance -- effect of being female rather than male for a 25 year old with no college education. ----
summary(glht(mod1, linfct = c("female + female_age*25 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_age*25 = 0"))))

describe(data$thermometer_feminist[data$male == 1 & data$age>19 & data$age<30 & data$college_educated==0])
mean20a <- describe(data$thermometer_feminist[data$male == 1 & data$age>19 & data$age<30 & data$college_educated==0])$mean; mean20a

((mod1$coefficients[2] + mod1$coefficients[6]*25)/mean20a)*100

#---- Modifying effect of college education in our scenarios ----
(mod1$coefficients[2] + mod1$coefficients[5] + mod1$coefficients[6]*25) - (mod1$coefficients[2] + mod1$coefficients[6]*25)

describe(data$thermometer_feminist)

#---- Substantive significance -- effect of being female rather than male for a 55 year old college graduate.	----
summary(glht(mod1, linfct = c("female + female_educated + female_age*55 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_educated + female_age*55 = 0"))))

describe(data$thermometer_feminist[data$male == 1 & data$age>49 & data$age<60 & data$college_educated==1])
mean50 <- describe(data$thermometer_feminist[data$male == 1 & data$age>49 & data$age<60 & data$college_educated==1])$mean; mean50

((mod1$coefficients[2] + mod1$coefficients[5] + mod1$coefficients[6]*55)/mean50)*100

#---- Compare effect size to when the individual was 25 ----
100-(((mod1$coefficients[2] + mod1$coefficients[5] + mod1$coefficients[6]*55)/(mod1$coefficients[2] + mod1$coefficients[5] + mod1$coefficients[6]*25))*100)

#----	Substantive significance -- effect of being female rather than male for a 55 year old with no college education. ----
summary(glht(mod1, linfct = c("female + female_age*55 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_age*55 = 0"))))

describe(data$thermometer_feminist[data$male == 1 & data$age>49 & data$age<60 & data$college_educated==0])
mean50a <- describe(data$thermometer_feminist[data$male == 1 & data$age>49 & data$age<60 & data$college_educated==0])$mean; mean50a

((mod1$coefficients[2] + mod1$coefficients[6]*55)/mean50a)*100

#---- Compare effect size to when the individual was 25	----
100-(((mod1$coefficients[2] + mod1$coefficients[6]*55)/(mod1$coefficients[2] + mod1$coefficients[6]*25))*100)

#---- Calculate information in Figure 6.10. ----
summary(glht(mod1, linfct = c("female + female_educated + female_age*25 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_educated + female_age*25 = 0"))))
summary(glht(mod1, linfct = c("female + female_age*25 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_age*25 = 0"))))

summary(glht(mod1, linfct = c("female + female_educated + female_age*55 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_educated + female_age*55 = 0"))))
summary(glht(mod1, linfct = c("female + female_age*55 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_age*55 = 0"))))

summary(glht(mod1, linfct = c("female_age*30 = 0")))
confint(summary(glht(mod1, linfct = c("female_age*30 = 0"))))
summary(glht(mod1, linfct = c("female_age*30 = 0")))
confint(summary(glht(mod1, linfct = c("female_age*30 = 0"))))
summary(glht(mod1, linfct = c("female_educated = 0")))
confint(summary(glht(mod1, linfct = c("female_educated= 0"))))
summary(glht(mod1, linfct = c("female_educated = 0")))
confint(summary(glht(mod1, linfct = c("female_educated= 0"))))

describe(data$thermometer_feminist[data$male==1 & data$age>19 & data$age<30 & data$college_educated==1])
describe(data$thermometer_feminist[data$male==1 & data$age>19 & data$age<30 & data$college_educated==0])
describe(data$thermometer_feminist[data$male==1 & data$age>49 & data$age<60 & data$college_educated==1])
describe(data$thermometer_feminist[data$male==1 & data$age>49 & data$age<60 & data$college_educated==0])

#---- Effect of education	----

#---- Effect of college education	for men	---- 
summary(glht(mod1, linfct = c("college_educated = 0")))
confint(summary(glht(mod1, linfct = c("college_educated = 0"))))

describe(data$thermometer_feminist[data$male==1 & data$college_educated==0])

#---- Effect of college education	for women	----
summary(glht(mod1, linfct = c("college_educated + female_educated = 0")))
confint(summary(glht(mod1, linfct = c("college_educated + female_educated = 0"))))

describe(data$thermometer_feminist[data$female==1 & data$college_educated==0])


#---- Compare effect of college education among women and men	-----
(mod1$coefficients[3] + mod1$coefficients[5])/(mod1$coefficients[3])

#----	Effect of age	----

#---- Effect of one additional year for men	----
summary(glht(mod1, linfct = c("age = 0")))
confint(summary(glht(mod1, linfct = c("age =  0"))))

#----	Effect of 30 additional years for men	----
summary(glht(mod1, linfct = c("age*30 = 0")))
confint(summary(glht(mod1, linfct = c("age*30 =  0"))))

#---- Mean level of support for feminism among men in the 20s ----
describe(data$thermometer_feminist[data$male==1 & data$age>19 & data$age<30])

#---- Effect of one additional year for women	----
summary(glht(mod1, linfct = c("age + female_age = 0")))
confint(summary(glht(mod1, linfct = c("age + female_age =  0"))))

#---- Effect of 30 additional years for women	----
summary(glht(mod1, linfct = c("(age + female_age)*30 = 0")))
confint(summary(glht(mod1, linfct = c("(age + female_age)*30 =  0"))))

#---- Additional control variables and interaction terms ----
summary(mod1)

mod2 <- lm(thermometer_feminist ~ female + college_educated + age + 
             female_educated + female_age + black + asian + native_american +
             hispanic + race_other + religion_important + left_right +
             married + income + employed, data)
summary(mod2)

data <- data %>%
  mutate(
    female_black = female*black,
    female_asian = female*asian,
    female_native = female*native_american,
    female_hispanic = female*hispanic,
    female_other = female*race_other,
    female_religion = female*religion_important,
    female_lr = female*left_right,
    female_married = female*married,
    female_income = female*income,
    female_employed = female*employed
  )

mod3 <- lm(thermometer_feminist ~ female + college_educated + age + female_educated + 
             female_age + black + asian + native_american + 
             hispanic + race_other + religion_important +  left_right + married + income + employed + 
             female_black + female_asian + female_native + female_hispanic + female_other +
             female_religion + female_lr + female_married + female_income + female_employed, data)
summary(mod3)

txtStop()