# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "margins", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(margins) #for margins
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter6_application2")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter6_application2")

txtStart("regime_collectdata_R.txt")

#---- Load in data ----
data <- read_dta('final.dta')

#---- Get just the labor (supply) variable ----
data <- data %>%
  filter(!is.na(labor)) %>%
  dplyr::select(labor)

write_csv(data, 'labor_R.csv')

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

#---- Get just the labor (supply) variable for democracy = 0 ----
data <- data %>%
  filter(!is.na(labor) & polity2 == 0) %>%
  dplyr::select(labor)

write_csv(data, 'labor0_R.csv')

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

#---- Get just the labor (supply) variable for democracy = 20 ----
data <- data %>%
  filter(!is.na(labor) & polity2 == 20) %>%
  dplyr::select(labor)

write_csv(data, 'labor20_R.csv')

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

#---- Get democracy and supply scores, but only for democracies ----
data <- data %>%
  filter(polity2 > 15) %>%
  dplyr::select(labor, polity2) %>%
  arrange(labor, polity2) %>%
  mutate(z = -1)

write_csv(data, 'obs_dem_R.csv')

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

#---- Get democracy and supply scores, but only for democracies ----
data <- data %>%
  filter(polity2 < 16) %>%
  dplyr::select(labor, polity2) %>%
  arrange(labor, polity2) %>%
  mutate(z = -1)

write_csv(data, 'obs_dic_R.csv')

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

#---- Get data to produce region of statistical significance that	goes with the marginal effect of demand shown in the 3-D plot shown in Figure 6.17a	----
mod1 <- lm(womens_representation ~ women_leaders * labor * polity2 + effectivequota, data)
summary(mod1)

#---- Strip 0 ----
laborvals <- seq(0, 10, 0.5)
polity2vals <- seq(0, 20, 0.1)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
      results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
      results <- rbind(results, results0)
      k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions0_R.csv')

#---- Strip 1 ----
laborvals <- seq(10, 20, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions10_R.csv')

#---- Strip 2 ----
laborvals <- seq(20, 30, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions20_R.csv')

#---- Strip 3 ----
laborvals <- seq(30, 40, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions30_R.csv')

#---- Strip 4 ----
laborvals <- seq(40, 50, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions40_R.csv')

#---- Strip 5 ----
laborvals <- seq(50, 60, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions50_R.csv')

#---- Strip 6 ----
laborvals <- seq(60, 70, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions60_R.csv')

#---- Strip 7 ----
laborvals <- seq(70, 80, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions70_R.csv')

#---- Strip 8 ----
laborvals <- seq(80, 90, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions80_R.csv')

#---- Strip 9 ----
laborvals <- seq(90, 100, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions90_R.csv')

#---- Strip 9 ----
laborvals <- seq(100, 111, 0.5)
polity2vals <- seq(0, 20, 0.5)
results <- matrix(NA, 4, 9)
k <- 1
for(i in laborvals){
  for(j in polity2vals){
    if(k == 1){
      results <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    }
    results0 <- summary(margins(mod1, at = list(labor = i, polity2 = j)))
    results <- rbind(results, results0)
    k <- k + 1
  }
}

results <- as.data.frame(results) %>%
  filter(factor == "women_leaders") %>%
  dplyr::select(labor, polity2, AME, p) %>%
  filter(p < 0.05) %>%
  rename(marginal_effect = AME,
         pvalue = p)

write_csv(results, 'predictions100_R.csv')

txtStop()