# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse","multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter6_exercise1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter6_exercise1")

txtStart("exercise1_analysis_R.txt")

#---- Load in data ----
data <- read_dta('anes2016_small.dta')

#---- Create dummy for college education, BA and up	----
data$college_educated <- ifelse(data$education > 12, 1, 0)
table(data$college_educated)

#---- Create interaction terms ----
data <- data %>%
  mutate(female_educated = female*college_educated,
         female_age=female*age)

#----	Produce results shown in Table 6.4 in Exercise 1 at the end	of Chapter 6	----
mod1 <- lm(thermometer_feminist ~ female + college_educated + age + 
             female_educated + female_age + black + asian + native_american +
             hispanic + race_other + religion_important + left_right, data)
summary(mod1)

df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t

#---- Requested standard errors are the square root of the relevant	diagonal elements of the variance-covariance matrix ----
vcov(mod1)

#---- Effect of being female rather than male for a 30 year old	college graduate. ----
summary(glht(mod1, linfct = c("female + female_educated + female_age*30 = 0")))
confint(summary(glht(mod1, linfct = c("female + female_educated + female_age*30 = 0"))))

txtStop()