# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "multcomp", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(multcomp) #for glht
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter6_exercise2")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter6_exercise2")

txtStart("exercise2_analysis_R.txt")

#---- Load in data ----
data <- read_dta('final.dta')

#---- Make polity variable go from 0 to 20 instead of -10 to +10 ----
data$polity2 <- data$polity + 10

table(data$polity2[data$year>1989])

#---- Create interaction terms ----
data <- data %>%
  mutate(
    leaders_labor = women_leaders*labor,
    leaders_polity2 = women_leaders*polity2,
    labor_polity2 = labor*polity2,
    leaders_labor_polity2 = women_leaders*labor*polity2,
    effectivequota_polity2 = effectivequota*polity2
  )

#---- Produce results shown in Table 6.5 in Chapter 6 ----
mod1 <- lm(womens_representation ~ women_leaders + labor + polity2 + 
             leaders_labor + leaders_polity2 + labor_polity2 + leaders_labor_polity2 +
             effectivequota, data)
summary(mod1)

df <- summary(mod1)$df[2]; df
t <- qt(0.025, df, lower.tail = FALSE); t

#---- Requested standard errors are the square root of the relevant	diagonal elements of the variance-covariance matrix ----
vcov(mod1)

#---- 20 unit increase in demand when supply is 80 and democracy is )15	----
summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*80 + leaders_polity2*15 + leaders_labor_polity2*80*15)*20 = 0")))
confint(summary(glht(mod1, linfct = c("(women_leaders + leaders_labor*80 + leaders_polity2*15 + leaders_labor_polity2*80*15)*20 = 0"))))

txtStop()