# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "msm", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter8_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter8_application")

txtStart("pec2_R.txt")

#---- Load in data ----
data <- read_dta('pec_BJPS.dta')

#---- Get polarization and threshold measures by election. ----
mean_data <- data %>%
  group_by(election) %>%
  dplyr::select(threshold, polarization) %>%
  summarise(across(threshold:polarization, mean))

describe(mean_data$threshold)
threshold_mean <- describe(mean_data$threshold)$mean; threshold_mean
threshold_sd <- describe(mean_data$threshold)$sd; threshold_sd

describe(mean_data$polarization)
polarization_mean <- describe(mean_data$polarization)$mean; polarization_mean
polarization_sd <- describe(mean_data$polarization)$sd; polarization_sd
polarization_25 <- quantile(mean_data$polarization, 0.25); polarization_25
polarization_75 <- quantile(mean_data$polarization, 0.75); polarization_75

describe(mean_data$election)
election_total <- describe(mean_data$election)$n; election_total

describe(mean_data$election[mean_data$threshold>16.74 & !is.na(mean_data$threshold)])
election_subtotal <- describe(mean_data$election[mean_data$threshold>16.74 & !is.na(mean_data$threshold)])$n; election_subtotal
(election_subtotal/election_total)*100

#---- Create some variables ----
data <- data %>%
  mutate(
    coalitionseatlag = seatlag1 + seatlag2,
    seatshare = coalitionseatlag*100,
    seatshare_2 = seatshare*seatshare,
    polarization_threshold = polarization*threshold) %>%
  apply_labels(
    seatshare = "size of potential coalition in percentage of seats",
    seatshare_2 = "seatshare squared"
  )

#---- Summary statistics ----
names(data)

data_sub <- dplyr::select(data, pec, seatshare, incompatibility, polarization, threshold)
describe(data_sub)

table(data$pec)

describe(data$polarization[data$polarization<83.7])

#---- Produce results shown in Table 8.2 in Chapter 8	----
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))

#---- Produce a figure like Figure 8.12 in R.----
# Effect of a	standard deviation increase in Disproportionality in a 
# representative baseline scenario where Disproportionality, 
# Seatshare, and Ideological Incompatibility are all at their	means.	

#---- Get values for our variables ----
describe(data$seatshare)
seatshare_mean <- describe(data$seatshare)$mean; seatshare_mean
seatshare_sd <- describe(data$seatshare)$sd; seatshare_sd
seatshare_plus <- seatshare_mean + seatshare_sd; seatshare_plus

describe(data$incompatibility)
incompatibility_mean <- describe(data$incompatibility)$mean; incompatibility_mean
incompatibility_sd <- describe(data$incompatibility)$sd; incompatibility_sd

threshold_plus <- threshold_mean + threshold_sd; threshold_plus
polarization_plus <- polarization_mean + polarization_sd; polarization_plus
constant <- 1

threshold_sd
threshold_mean
threshold_plus
polarization_sd
polarization_mean
polarization_plus
seatshare_sd
seatshare_mean
seatshare_plus
incompatibility_sd
incompatibility_mean
constant

summary(mod1)

set.seed(10101)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))


lo0 <- vector()
hi0 <- vector()
lo1 <- vector()
hi1 <- vector()
diff_lo <- vector()
diff_hi <- vector()
percent_lo <- vector()
percent_hi <- vector()
prob_hat0 <- vector()
prob_hat1 <- vector()
diff_hat <- vector()
percent_hat <- vector()
lo0c <- vector()
hi0c <- vector()
lo1c <- vector()
hi1c <- vector()
diff_loc <- vector()
diff_hic <- vector()
diff_diff_lo <- vector()
diff_diff_hi <- vector()
prob_hat0c <- vector()
prob_hat1c <- vector()
diff_hatc <- vector()
diff_diff_hat <- vector()
percentc_lo <- vector()
percentc_hi <- vector()
diff_percent_lo <- vector()
diff_percent_hi <- vector()
percentc_hat <- vector()
diff_percent_hat <- vector()

a <- 0
j <- 1
while(a <= 100.1){
 
  #---- xbeta in baseline	----
  x_betahat0 <- sim[,  2]*threshold_mean + sim[,  3]*a + sim[,  4]*threshold_mean*a +
    sim[,  5]*seatshare_mean + sim[,  6]*seatshare_mean*seatshare_mean + sim[,  7]*incompatibility_mean +
    sim[,  1]*constant
  
  #---- xbeta in counterfactual ----
  x_betahat1 <- sim[,  2]*threshold_plus + sim[,  3]*a + sim[,  4]*threshold_plus*a +
    sim[,  5]*seatshare_mean + sim[,  6]*seatshare_mean*seatshare_mean + sim[,  7]*incompatibility_mean + 
    sim[,  1]*constant
      
  #---- Probability in baseline	and counterfactual ----
  prob0 <- exp(x_betahat0)/(1+exp(x_betahat0))
  prob1 <- exp(x_betahat1)/(1+exp(x_betahat1))
      
  #---- Change and percentage change in probability ----
  diff  <- prob1 - prob0 
  percent  <- (diff /prob0)*100		
  probhat0 <- mean(prob0)
  probhat1 <- mean(prob1)
  diffhat <- mean(diff)
  percenthat <- mean(percent)
      
  #---- Get information for modifying effect of a one unit increase in polarization ----
  x_betahat0c <- sim[,  2]*threshold_mean + sim[,  3]*(a+1) + sim[,  4]*threshold_mean*(a+1) +
    sim[,  5]*seatshare_mean + sim[,  6]*seatshare_mean*seatshare_mean + sim[,  7]*incompatibility_mean +
    sim[,  1]*constant
      
  x_betahat1c <- sim[,  2]*threshold_plus + sim[,  3]*(a+1) + sim[,  4]*threshold_plus*(a+1) +
    sim[,  5]*seatshare_mean + sim[,  6]*seatshare_mean*seatshare_mean + sim[,  7]*incompatibility_mean +
    sim[,  1]*constant
  
  prob0c <- exp(x_betahat0c)/(1+exp(x_betahat0c))
  prob1c <- exp(x_betahat1c)/(1+exp(x_betahat1c))
  diffc <- prob1c-prob0c
  diff_diff <- diffc-diff
  percentc <- (diffc/prob0c)*100
  diff_percent <- percentc-percent	
  
  probhat0c <- mean(prob0c)
  probhat1c <- mean(prob1c)
  diffhatc <- mean(diffc)
  diff_diffhat <- mean(diff_diff)
  percentchat <- mean(percentc)
  diff_percenthat <- mean(diff_percent)
  
  lo0[j] <- quantile(prob0, 0.025)
  hi0[j] <- quantile(prob0, 0.975)
  
  lo1[j] <- quantile(prob1, 0.025)
  hi1[j] <- quantile(prob1, 0.975)
  
  diff_lo[j] <- quantile(diff, 0.025)
  diff_hi[j] <- quantile(diff, 0.975)
  
  percent_lo[j] <- quantile(percent, 0.025)
  percent_hi[j] <- quantile(percent, 0.975)
  
  prob_hat0[j] <- probhat0
  prob_hat1[j] <- probhat1
  diff_hat[j] <- diffhat
  percent_hat[j] <- percenthat
  
  lo0c[j] <- quantile(prob0c, 0.025)
  hi0c[j] <- quantile(prob0c, 0.975)
  
  lo1c[j] <- quantile(prob1c, 0.025)
  hi1c[j] <- quantile(prob1c, 0.975)
  
  diff_loc[j] <- quantile(diffc, 0.025)
  diff_hic[j] <- quantile(diffc, 0.975)
  
  diff_diff_lo[j] <- quantile(diff_diff, 0.025)
  diff_diff_hi[j] <- quantile(diff_diff, 0.975)
  
  prob_hat0c[j] <- probhat0c
  prob_hat1c[j] <- probhat1c
  diff_hatc[j] <- diffhatc
  diff_diff_hat[j] <- diff_diffhat
  
  percentc_lo[j] <- quantile(percentc, 0.025)
  percentc_hi[j] <- quantile(percentc, 0.975)
  
  diff_percent_lo[j] <- quantile(diff_percent, 0.025)
  diff_percent_hi[j] <- quantile(diff_percent, 0.975)
  
  percentc_hat[j] <- percentchat
  diff_percent_hat[j] <- diff_percenthat
    
  a <- a + 0.1
  j <- j + 1
 
}

sim_data <- as.data.frame(cbind(prob_hat0, lo0, hi0, prob_hat1, lo1, hi1, diff_hat, diff_lo, diff_hi, percent_hat, percent_lo, percent_hi, prob_hat0c, lo0c, hi0c, prob_hat1c, lo1c, hi1c, diff_hatc, diff_loc, diff_hic, diff_diff_hat, diff_diff_lo, diff_diff_hi, percentc_hat, percentc_lo, percentc_hi, diff_percent_hat, diff_percent_lo, diff_percent_hi
))

sim_data <- sim_data[1:1001, ]
n <- 1:1001
MV <- (n-1)/10

#---- Figure 8.12a. ----
# The histogram differs slightly from the one shown in Figure 8.12a because the 
# bar widths and locations are not identical.

ggplot() +
  geom_line(aes(x = MV, y = sim_data$diff_hat)) +
  geom_line(aes(x = MV, y = sim_data$diff_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$diff_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$polarization, y = (..count..)/sum(..count..)*100/50), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Change in Probability",
    sec.axis = sec_axis(~.*50, name="Percentage of Observations")
  ) +
  xlab("Polarization") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")

#---- Figure 8.12b. ----
# The histogram differs slightly from the one shown in Figure 8.12b because the 
# bar widths and locations are not identical.


ggplot() +
  geom_line(aes(x = MV, y = sim_data$percent_hat)) +
  geom_line(aes(x = MV, y = sim_data$percent_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$percent_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$polarization, y = (..count..)/sum(..count..)*100*20), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Percentage Change in Probability",
    sec.axis = sec_axis(~./20, name="Percentage of Observations")
  ) +
  xlab("Polarization") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")

sim_data %>%
  filter(MV==10) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)
sim_data %>%
  filter(MV==29.5) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)
sim_data %>%
  filter(MV==49) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)

#---- Figure 8.12c. ----
# The histogram differs slightly from the one shown in Figure 8.12c because the 
# bar widths and locations are not identical.
ggplot() +
  geom_line(aes(x = MV, y = sim_data$diff_diff_hat)) +
  geom_line(aes(x = MV, y = sim_data$diff_diff_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$diff_diff_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$polarization, y = (..count..)/sum(..count..)*100/1000), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Interaction Effect",
    sec.axis = sec_axis(~.*1000, name="Percentage of Observations")
  ) +
  xlab("Polarization") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")

sim_data %>%
  filter(MV==29.5) %>%
  dplyr::select(diff_diff_hat, diff_diff_lo, diff_diff_hi)

#---- Let's calculate effect of a one standard deviation increase in Disproportionality on the probability of pre-electoral coalition formation for all of our sample observations ----

#---- Predicted probability of PEC formation for sample observations using R's in-built command ----
summary(mod1)
mod1$fitted.values
describe(mod1$fitted.values)

#---- Predicted probability of PEC formation for sample observations in baseline scenario defined by sample values. ----
# This will give the same values as phat and can be used as a check that code is correct	
esample <- rownames(as.matrix(resid(mod1)))
esamp <- data[esample, ]
prob_base <- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                   mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                   mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                   mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
             mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))

prob_base_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i]
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_base_se[i] <- deltamethod(~ exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                 x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                           (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                    x5*seatshare + x6*seatshare2 + x7*incompatibility)), coef(mod1), vcov(mod1))
}
  
#---- Predicted probability of PEC formation for sample observations in counterfactual scenario where we increase Disproportionality	by a standard deviation	----
prob_counterfactual <- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
                   mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
                   mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                   mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
             mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))

prob_counterfactual_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i] 
  threshold_plus_sd <- esamp$threshold[i] + threshold_sd
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_counterfactual_se[i] <- deltamethod(~ exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                      x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                (1+exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                         x5*seatshare + x6*seatshare2 + x7*incompatibility)), coef(mod1), vcov(mod1))
}
#---- Change in predicted probability of PEC formation for sample from baseline to counterfactual scenario ----
change <- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
                mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
                mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
             mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility)) - exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
                                                                 mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
                                                                 mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                 mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
             mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))


prob_change_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i] 
  threshold_plus_sd <- esamp$threshold[i] + threshold_sd
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_change_se[i] <- deltamethod(~ (exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                   x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                             (1+exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                      x5*seatshare + x6*seatshare2 + x7*incompatibility)) - 
                                        (exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                               x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                           (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                    x5*seatshare + x6*seatshare2 + x7*incompatibility)))), coef(mod1), vcov(mod1))
}
  #---- Percent change in predicted probability of PEC formation for sample from baseline to counterfactual scenario ----
percentage_change <- (exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
                            mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
                            mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                            mod1$coefficients[7]*esamp$incompatibility)/
                        (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
                                   mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization*(esamp$threshold + threshold_sd)) +
                                   mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                   mod1$coefficients[7]*esamp$incompatibility)) - exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
                                                                                        mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
                                                                                        mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                        mod1$coefficients[7]*esamp$incompatibility)/
                        (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
                                   mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
                                   mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                   mod1$coefficients[7]*esamp$incompatibility))) / (exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
                                                                                          mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
                                                                                          mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                          mod1$coefficients[7]*esamp$incompatibility)/
                                                                                      (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*esamp$threshold +
                                                                                                 mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*esamp$polarization_threshold +
                                                                                                 mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                 mod1$coefficients[7]*esamp$incompatibility)))*100
  
prob_percentchange_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i] 
  threshold_plus_sd <- esamp$threshold[i] + threshold_sd
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_percentchange_se[i] <- deltamethod(~ (exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                            x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                        (1+exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                 x5*seatshare + x6*seatshare2 + x7*incompatibility)) - 
                                        (exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                               x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                           (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                    x5*seatshare + x6*seatshare2 + x7*incompatibility))))/( (exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                                                                                   x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                                                                                               (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                                                                                        x5*seatshare + x6*seatshare2 + x7*incompatibility)))) *100, coef(mod1), vcov(mod1))
}

#---- Get mean, min, and max for change and percentage change across our sample observations. ----
describe(change)
describe(percentage_change)

#---- Compare to percentage change when our variables were set at their means that we calculated earlier.	----
sim_data %>%
  filter(MV==29.5) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)

#---- Produce a figure like Figure 8.13 in R. ----
# Show how the effect of a standard deviation increase in Disproportionality on the
# probability of pre-electoral coalition formation varies with the value of Polarization
# across the sample observations. Note that the figures in the book were created using pgfplots, not R.	
z <- qnorm(0.975)
lower_percentage_change <- percentage_change - (z*prob_percentchange_se)
upper_percentage_change <- percentage_change + (z*prob_percentchange_se)

#---- Get error for error bars for percentage change ----
error1 <- z*prob_change_se

#---- Produce Figure 8.13 ----
ggplot() +
  geom_errorbar(aes(x = esamp$polarization, ymin = lower_percentage_change, ymax = upper_percentage_change), width = 1, color = "gray") +
  geom_point(aes(x = esamp$polarization, y = percentage_change), color = "blue") +
  geom_hline(yintercept =  0, lty = "dashed") + 
  theme_bw() + 
  labs(x = "Party System Polarization", y = "Percentage Change in Probability of PEC Formation")

#---- There are no confidence intervals that cross the zero line. ----
describe(lower_percentage_change[lower_percentage_change<0])

#---- Compare percentage change between elections with values of polarization in the lowest quartile to those with values in the highest quartile.	----
describe(percentage_change[esamp$polarization<polarization_25])
percentage_change25 <- describe(percentage_change[esamp$polarization<polarization_25])$mean; percentage_change25
describe(percentage_change[esamp$polarization>polarization_75])
percentage_change75 <- describe(percentage_change[esamp$polarization>polarization_75])$mean; percentage_change75

percentage_change75/percentage_change25

#---- Get at modifying effect of one unit increase in Polarization ----

#---- Obtain predicted probability for each observation in the new baseline scenario where polarization is one unit higher than before. ----
prob_base2 <- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                   mod1$coefficients[3]*(esamp$polarization+1) + mod1$coefficients[4]*(esamp$threshold*(esamp$polarization+1)) +
                   mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                   mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
             mod1$coefficients[3]*(esamp$polarization +1)+ mod1$coefficients[4]*(esamp$threshold*(esamp$polarization+1)) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))

prob_base2_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i] + 1
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_base2_se[i] <- deltamethod(~ exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                         x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                   (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                            x5*seatshare + x6*seatshare2 + x7*incompatibility)), coef(mod1), vcov(mod1))
}

#---- Obtain predicted probability for each observation in the newcounterfactual scenario where polarization is one unit higher than before.	----
prob_counterfactual2 <- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
                             mod1$coefficients[3]*(esamp$polarization+1) + mod1$coefficients[4]*(((esamp$polarization+1))*(esamp$threshold + threshold_sd)) +
                             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                             mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold + threshold_sd) +
             mod1$coefficients[3]*(esamp$polarization+1) + mod1$coefficients[4]*(((esamp$polarization+1))*(esamp$threshold + threshold_sd)) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))

prob_counterfactual2_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i] +1
  threshold_plus_sd <- esamp$threshold[i] + threshold_sd
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_counterfactual2_se[i] <- deltamethod(~ exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                   x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                             (1+exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                      x5*seatshare + x6*seatshare2 + x7*incompatibility)), coef(mod1), vcov(mod1))
}

#---- We can now calculate the interaction effect as (prob_counterfactual2 - prob_base2) minus	(prob_counterfactual - prob_base) ----
interaction_effect <- (prob_counterfactual2-prob_base2) - (prob_counterfactual-prob_base)


prob_interaction_effect_se <- vector()
for(i in 1:length(esamp$countryname)){
  polarization_plus1 <- esamp$polarization[i]  + 1
  polarization <- esamp$polarization[i] 
  threshold_plus_sd <- esamp$threshold[i] + threshold_sd
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  prob_interaction_effect_se[i] <- deltamethod(~ (exp(x1 + x2*threshold_plus_sd + x3*polarization_plus1 + x4*polarization_plus1*threshold_plus_sd +
                                            x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                        (1+exp(x1 + x2*threshold_plus_sd + x3*polarization_plus1 + x4*polarization_plus1*threshold_plus_sd +
                                                 x5*seatshare + x6*seatshare2 + x7*incompatibility)) - exp(x1 + x2*threshold + x3*polarization_plus1 + x4*polarization_plus1*threshold +
                                                                                                             x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                        (1+exp(x1 + x2*threshold + x3*polarization_plus1 + x4*polarization_plus1*threshold +
                                                 x5*seatshare + x6*seatshare2 + x7*incompatibility)) -(exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                                                                             x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                                                                                         (1+exp(x1 + x2*threshold_plus_sd + x3*polarization + x4*polarization*threshold_plus_sd +
                                                                                                                  x5*seatshare + x6*seatshare2 + x7*incompatibility)) - 
                                                                                                         (exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                                                                                x5*seatshare + x6*seatshare2 + x7*incompatibility)/
                                                                                                            (1+exp(x1 + x2*threshold + x3*polarization + x4*polarization*threshold +
                                                                                                                     x5*seatshare + x6*seatshare2 + x7*incompatibility))))), coef(mod1), vcov(mod1))
}
#---- If we wanted to, we can also calculate the interaction effect	in terms of marginal effects. ----
interaction_effect_me <- (exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
      mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
      mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
      mod1$coefficients[7]*esamp$incompatibility)/
  (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
             mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
             mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
             mod1$coefficients[7]*esamp$incompatibility))*(1-exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                 mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                 mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                 mod1$coefficients[7]*esamp$incompatibility)/
                                                             (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                        mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                        mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                        mod1$coefficients[7]*esamp$incompatibility)))*mod1$coefficients[4]) + (exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                    mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                    mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                    mod1$coefficients[7]*esamp$incompatibility)/
                                                                                                                                                (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                           mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                           mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                           mod1$coefficients[7]*esamp$incompatibility))*(1- exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                                                                               mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                                                                               mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                                                                               mod1$coefficients[7]*esamp$incompatibility)/
                                                                                                                                                                                                           (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                                                                                      mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                                                                                      mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                                                                                      mod1$coefficients[7]*esamp$incompatibility)))) * (1-2*exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                                                                                                                                                mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                                                                                                                                                mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                                                                                                                                                mod1$coefficients[7]*esamp$incompatibility)/
                                                                                                                                                                                                                                                                          (1 + exp(mod1$coefficients[1] + mod1$coefficients[2]*(esamp$threshold) +
                                                                                                                                                                                                                                                                                     mod1$coefficients[3]*esamp$polarization + mod1$coefficients[4]*(esamp$polarization_threshold) +
                                                                                                                                                                                                                                                                                     mod1$coefficients[5]*esamp$seatshare + mod1$coefficients[6]*esamp$seatshare_2 +
                                                                                                                                                                                                                                                                                     mod1$coefficients[7]*esamp$incompatibility))) *
(  mod1$coefficients[2] + mod1$coefficients[4]*esamp$polarization) * (mod1$coefficients[3] + mod1$coefficients[4]*(esamp$threshold)) 


se_interaction_me <- vector()
for(i in 1:length(esamp$countryname)){
  polarization <- esamp$polarization[i]
  threshold <- esamp$threshold[i]
  seatshare <- esamp$seatshare[i]
  seatshare2 <- esamp$seatshare_2[i]
  incompatibility <- esamp$incompatibility[i]
  
  se_interaction_me[i] <- deltamethod(~ (exp(x1 + x2*(threshold) +
                                               x3*polarization + x4*(polarization*threshold) +
                                               x5*seatshare + x6*seatshare2 +
                                               x7*incompatibility)/
                                           (1 + exp(x1 + x2*(threshold) +
                                                      x3*polarization + x4*(polarization*threshold) +
                                                      x5*seatshare + x6*seatshare2 +
                                                      x7*incompatibility))*(1-exp(x1 + x2*(threshold) +
                                                                                    x3*polarization + x4*(polarization*threshold) +
                                                                                    x5*seatshare + x6*seatshare2 +
                                                                                    x7*incompatibility)/
                                                                              (1 + exp(x1 + x2*(threshold) +
                                                                                         x3*polarization + x4*(polarization*threshold) +
                                                                                         x5*seatshare + x6*seatshare2 +
                                                                                         x7*incompatibility)))*x4) + (exp(x1 + x2*(threshold) +
                                                                                                                            x3*polarization + x4*(polarization*threshold) +
                                                                                                                            x5*seatshare + x6*seatshare2 +
                                                                                                                            x7*incompatibility)/
                                                                                                                        (1 + exp(x1 + x2*(threshold) +
                                                                                                                                   x3*polarization + x4*(polarization*threshold) +
                                                                                                                                   x5*seatshare + x6*seatshare2 +
                                                                                                                                   x7*incompatibility))*(1- exp(x1 + x2*(threshold) +
                                                                                                                                                                  x3*polarization + x4*(polarization*threshold) +
                                                                                                                                                                  x5*seatshare + x6*seatshare2 +
                                                                                                                                                                  x7*incompatibility)/
                                                                                                                                                           (1 + exp(x1 + x2*(threshold) +
                                                                                                                                                                      x3*polarization + x4*(polarization*threshold) +
                                                                                                                                                                      x5*seatshare + x6*seatshare2 +
                                                                                                                                                                      x7*incompatibility)))) * (1-2*exp(x1 + x2*(threshold) +
                                                                                                                                                                                                          x3*polarization + x4*(polarization*threshold) +
                                                                                                                                                                                                          x5*seatshare + x6*seatshare2 +
                                                                                                                                                                                                          x7*incompatibility)/
                                                                                                                                                                                                  (1 + exp(x1 + x2*(threshold) +
                                                                                                                                                                                                             x3*polarization + x4*(polarization*threshold) +
                                                                                                                                                                                                             x5*seatshare + x6*seatshare2 +
                                                                                                                                                                                                             x7*incompatibility))) *
                                        (  x2 + x4*polarization) * (x3 + x4*(threshold)), coef(mod1), vcov(mod1))

}

#---- Min, max, and mean modifying effect of a one-unit increase in polarization on a one standard deviation increase in disproportionalityacross the sample observations. ----
describe(interaction_effect)

#---- Compare to same interaction (modifying) effect when our	variables were set at their means that we calculated earlier. ----
sim_data %>%
  filter(MV==29.5) %>%
  dplyr::select(diff_diff_hat, diff_diff_lo, diff_diff_hi)

#---- Produce a figure like Figure 8.14 in R. ----
# Show how the interaction effect varies with the probability of pre-electoral 
# coalition formation. Note that the figures in the book were created using pgfplots, not R

lower_interaction_effect = interaction_effect-(z*prob_interaction_effect_se)
upper_interaction_effect = interaction_effect+(z*prob_interaction_effect_se)

#---- Get error for error bars for interaction effect	----
error <- z*prob_interaction_effect_se

#---- Figure 8.14 ----
ggplot() +
  geom_errorbar(aes(x = prob_base, ymin = lower_interaction_effect, ymax = upper_interaction_effect), width = 0.01, color = "gray") +
  geom_point(aes(x = prob_base, y = interaction_effect), color = "blue") +
  geom_smooth(aes(x = prob_base, y = interaction_effect), method = "loess", size = 1, color = "black", se = F) +
  geom_hline(yintercept =  0, lty = "dashed") + 
  theme_bw() + 
  labs(x = "Probability of Pre-Electoral Coalition Formation", y = "Interaction Effect")

#---- We could also add lowess curves for confidence intervals. Lowess curves for confidence intervals are always positive	----
ggplot() +
  geom_errorbar(aes(x = prob_base, ymin = lower_interaction_effect, ymax = upper_interaction_effect), width = 0.01, color = "gray") +
  geom_point(aes(x = prob_base, y = interaction_effect), color = "blue") +
  geom_smooth(aes(x = prob_base, y = interaction_effect), method = "loess", size = 1, color = "black", se = F) +
  geom_smooth(aes(x = prob_base, y = lower_interaction_effect), method = "loess", size = 1, color = "black", se = F, lty ="dotted") +
  geom_smooth(aes(x = prob_base, y = upper_interaction_effect), method = "loess", size = 1, color = "black", se = F, lty ="dotted") +
  geom_hline(yintercept =  0, lty = "dashed") + 
  theme_bw() + 
  labs(x = "Probability of Pre-Electoral Coalition Formation", y = "Interaction Effect")

#---- Confidence intervals that cross the zero line	----
describe(lower_interaction_effect)
obs <- describe(lower_interaction_effect)$n; obs

describe(lower_interaction_effect[lower_interaction_effect<0])
number <- describe(lower_interaction_effect[lower_interaction_effect<0])$n; number

(1-(number/obs))*100

txtStop()