# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss) #for apply_labels
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter8_application")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter8_application")

txtStart("pec4_R.txt")

#---- Load in data ----
data <- read_dta('pec_BJPS.dta')

#---- Get polarization and threshold measures by election. ----
mean_data <- data %>%
  group_by(election) %>%
  dplyr::select(threshold, polarization) %>%
  summarise(across(threshold:polarization, mean))

describe(mean_data$threshold)
threshold_mean <- describe(mean_data$threshold)$mean; threshold_mean
threshold_sd <- describe(mean_data$threshold)$sd; threshold_sd

describe(mean_data$polarization)
polarization_mean <- describe(mean_data$polarization)$mean; polarization_mean
polarization_sd <- describe(mean_data$polarization)$sd; polarization_sd

#---- Create some variables ----
data <- data %>%
  mutate(
    coalitionseatlag = seatlag1 + seatlag2,
    seatshare = coalitionseatlag*100,
    seatshare_2 = seatshare*seatshare,
    polarization_threshold = polarization*threshold) %>%
  apply_labels(
    seatshare = "size of potential coalition in percentage of seats",
    seatshare_2 = "seatshare squared"
  )

#---- Produce results shown in Table 8.2 in Chapter 8	----
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + seatshare +
              seatshare_2 + incompatibility, data, family = binomial(link = "logit"))
summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))

#---- Produce a figure like Figure 8.16 in R. ----
# Effect of a ten unit increase in Coalition Size on the probability of PEC	
# formation when Disproportionality, Seatshare, and Ideological Incompatibility 
# are all at their means.		

#---- Get values for our variables ----
describe(data$seatshare)
seatshare_mean <- describe(data$seatshare)$mean; seatshare_mean
seatshare_sd <- describe(data$seatshare)$sd; seatshare_sd
seatshare_plus <- seatshare_mean + seatshare_sd; seatshare_plus

describe(data$incompatibility)
incompatibility_mean <- describe(data$incompatibility)$mean; incompatibility_mean
incompatibility_sd <- describe(data$incompatibility)$sd; incompatibility_sd

threshold_plus <- threshold_mean + threshold_sd; threshold_plus
polarization_plus <- polarization_mean + polarization_sd; polarization_plus
constant <- 1

threshold_sd
threshold_mean
threshold_plus
polarization_sd
polarization_mean
polarization_plus
seatshare_sd
seatshare_mean
seatshare_plus
incompatibility_sd
incompatibility_mean
constant

summary(mod1)

set.seed(10101)
sim <- mvrnorm(n = 10000, mu = mod1$coefficients, Sigma = vcov(mod1))


lo0 <- vector()
hi0 <- vector()
lo1 <- vector()
hi1 <- vector()
diff_lo <- vector()
diff_hi <- vector()
percent_lo <- vector()
percent_hi <- vector()
prob_hat0 <- vector()
prob_hat1 <- vector()
diff_hat <- vector()
percent_hat <- vector()
lo0c <- vector()
hi0c <- vector()
lo1c <- vector()
hi1c <- vector()
diff_loc <- vector()
diff_hic <- vector()
diff_diff_lo <- vector()
diff_diff_hi <- vector()
prob_hat0c <- vector()
prob_hat1c <- vector()
diff_hatc <- vector()
diff_diff_hat <- vector()
percentc_lo <- vector()
percentc_hi <- vector()
diff_percent_lo <- vector()
diff_percent_hi <- vector()
percentc_hat <- vector()
diff_percent_hat <- vector()

a <- 0
j <- 1
while(a <= 100.1){
 
  #---- xbeta in baseline	----
  x_betahat0 <- sim[,  2]*threshold_mean + sim[,  3]*polarization_mean + sim[,  4]*threshold_mean*polarization_mean +
    sim[,  5]*a + sim[,  6]*a*a + sim[,  7]*incompatibility_mean +
    sim[,  1]*constant
  
  #---- xbeta in counterfactual ----
  x_betahat1 <- sim[,  2]*threshold_mean + sim[,  3]*polarization_mean + sim[,  4]*threshold_mean*polarization_mean +
    sim[,  5]*(a+10) + sim[,  6]*(a+10)*(a+10) + sim[,  7]*incompatibility_mean + 
    sim[,  1]*constant
      
  #---- Probability in baseline	and counterfactual ----
  prob0 <- exp(x_betahat0)/(1+exp(x_betahat0))
  prob1 <- exp(x_betahat1)/(1+exp(x_betahat1))
      
  #---- Change and percentage change in probability ----
  diff  <- prob1 - prob0 
  percent  <- (diff /prob0)*100		
  probhat0 <- mean(prob0)
  probhat1 <- mean(prob1)
  diffhat <- mean(diff)
  percenthat <- mean(percent)
      
  #---- Get information for modifying effect of a one unit increase in coalition size ----
  x_betahat0c <- sim[,  2]*threshold_mean + sim[,  3]*polarization_mean + sim[,  4]*threshold_mean*polarization_mean +
    sim[,  5]*(a+1) + sim[,  6]*(a+1)*(a+1) + sim[,  7]*incompatibility_mean +
    sim[,  1]*constant
      
  x_betahat1c <- sim[,  2]*threshold_mean + sim[,  3]*polarization_mean + sim[,  4]*threshold_mean*polarization_mean +
    sim[,  5]*(a+11) + sim[,  6]*(a+11)*(a+11) + sim[,  7]*incompatibility_mean + 
    sim[,  1]*constant
  
  prob0c <- exp(x_betahat0c)/(1+exp(x_betahat0c))
  prob1c <- exp(x_betahat1c)/(1+exp(x_betahat1c))
  diffc <- prob1c-prob0c
  diff_diff <- diffc-diff
  percentc <- (diffc/prob0c)*100
  diff_percent <- percentc-percent	
  
  probhat0c <- mean(prob0c)
  probhat1c <- mean(prob1c)
  diffhatc <- mean(diffc)
  diff_diffhat <- mean(diff_diff)
  percentchat <- mean(percentc)
  diff_percenthat <- mean(diff_percent)
  
  lo0[j] <- quantile(prob0, 0.025)
  hi0[j] <- quantile(prob0, 0.975)
  
  lo1[j] <- quantile(prob1, 0.025)
  hi1[j] <- quantile(prob1, 0.975)
  
  diff_lo[j] <- quantile(diff, 0.025)
  diff_hi[j] <- quantile(diff, 0.975)
  
  percent_lo[j] <- quantile(percent, 0.025)
  percent_hi[j] <- quantile(percent, 0.975)
  
  prob_hat0[j] <- probhat0
  prob_hat1[j] <- probhat1
  diff_hat[j] <- diffhat
  percent_hat[j] <- percenthat
  
  lo0c[j] <- quantile(prob0c, 0.025)
  hi0c[j] <- quantile(prob0c, 0.975)
  
  lo1c[j] <- quantile(prob1c, 0.025)
  hi1c[j] <- quantile(prob1c, 0.975)
  
  diff_loc[j] <- quantile(diffc, 0.025)
  diff_hic[j] <- quantile(diffc, 0.975)
  
  diff_diff_lo[j] <- quantile(diff_diff, 0.025)
  diff_diff_hi[j] <- quantile(diff_diff, 0.975)
  
  prob_hat0c[j] <- probhat0c
  prob_hat1c[j] <- probhat1c
  diff_hatc[j] <- diffhatc
  diff_diff_hat[j] <- diff_diffhat
  
  percentc_lo[j] <- quantile(percentc, 0.025)
  percentc_hi[j] <- quantile(percentc, 0.975)
  
  diff_percent_lo[j] <- quantile(diff_percent, 0.025)
  diff_percent_hi[j] <- quantile(diff_percent, 0.975)
  
  percentc_hat[j] <- percentchat
  diff_percent_hat[j] <- diff_percenthat
    
  a <- a + 0.1
  j <- j + 1
 
}

sim_data <- as.data.frame(cbind(prob_hat0, lo0, hi0, prob_hat1, lo1, hi1, diff_hat, diff_lo, diff_hi, percent_hat, percent_lo, percent_hi, prob_hat0c, lo0c, hi0c, prob_hat1c, lo1c, hi1c, diff_hatc, diff_loc, diff_hic, diff_diff_hat, diff_diff_lo, diff_diff_hi, percentc_hat, percentc_lo, percentc_hi, diff_percent_hat, diff_percent_lo, diff_percent_hi
))

sim_data <- sim_data[1:1001, ]
n <- 1:1001
MV <- (n-1)/10

#---- Figure 8.16a. ----
# The histogram differs slightly from the one shown in Figure 8.16a because the 
# bar widths and locations are not identical.

ggplot() +
  geom_line(aes(x = MV, y = sim_data$diff_hat)) +
  geom_line(aes(x = MV, y = sim_data$diff_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$diff_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$seatshare, y = (..count..)/sum(..count..)*100/250), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Change in Probability",
    sec.axis = sec_axis(~.*250, name="Percentage of Observations")
  ) +
  xlab("Expected CoaltiON Size") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")


#---- Information about percentage of observations in different	regions based on marginal effect plot. ----
describe(data$seatshare)
total <- describe(data$seatshare)$n; total

describe(data$seatshare[data$seatshare<22.7])
subtotal1 <- describe(data$seatshare[data$seatshare<22.7])$n; subtotal1
(subtotal1/total)*100

describe(data$seatshare[data$seatshare>41.5 & !is.na(data$seatshare)])
subtotal2 <- describe(data$seatshare[data$seatshare>41.5 & !is.na(data$seatshare)])$n; subtotal2
(subtotal2/total)*100

#---- Figure 8.16b. ----
# The histogram differs slightly from the one shown in Figure 8.16b because the 
# bar widths and locations are not identical.

ggplot() +
  geom_line(aes(x = MV, y = sim_data$percent_hat)) +
  geom_line(aes(x = MV, y = sim_data$percent_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$percent_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$seatshare, y = (..count..)/sum(..count..)*100*10), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Percentage Change in Probability",
    sec.axis = sec_axis(~./10, name="Percentage of Observations")
  ) +
  xlab("Expected Coalition Size") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")

#---- Some specific values ----
sim_data %>%
  filter(n==103) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)
sim_data %>%
  filter(n==315) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)
sim_data %>%
  filter(n==526) %>%
  dplyr::select(percent_hat, percent_lo, percent_hi)

#---- Figure 8.16c. ----
# The histogram differs slightly from the one shown in Figure 8.16c because the 
# bar widths and locations are not identical.
ggplot() +
  geom_line(aes(x = MV, y = sim_data$diff_diff_hat)) +
  geom_line(aes(x = MV, y = sim_data$diff_diff_lo), lty = "dashed", color = "blue") +
  geom_line(aes(x = MV, y = sim_data$diff_diff_hi), lty = "dashed", color = "blue") +
  geom_histogram(aes(x = data$seatshare, y = (..count..)/sum(..count..)*100/10000), alpha = 0.1) +
  theme_bw() + 
  scale_y_continuous(
    name = "Self-Interaction Effect",
    sec.axis = sec_axis(~.*10000, name="Percentage of Observations")
  ) +
  xlab("Expected Coalition Size") +
  theme(axis.title.y.right = element_text(color = "gray"))  +
  geom_hline(yintercept = 0, lty = "solid")

#---- Some specific values ----
# Some of the numbers may not be exact matches to the those in Stata or in the book.
# This is because statistical software have different ways of recording floating point numbers.
# For example, when filtering values of seatshare <55, some software also include 55.000001 as being less than 55.
describe(data$seatshare)
total <- describe(data$seatshare)$n; total

describe(data$seatshare[data$seatshare>9.2 & data$seatshare<55])
subtotal1 <- describe(data$seatshare[data$seatshare>9.2 & data$seatshare<55])$n; subtotal1
(subtotal1/total)*100

describe(data$seatshare[data$seatshare>82.8])
subtotal2 <- describe(data$seatshare[data$seatshare>82.8])$n; subtotal2
(subtotal2/total)*100

txtStop()