# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "expss", "msm", "margins", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation
library(psych) #to describe data
library(multcomp) #for glht
library(expss)  #for apply_labels
library(msm) #for deltamethod
library(margins) #for margins
library(TeachingDemos) #for txtStart

# Set working directory
#setwd("~/Dropbox/ali/replications/chapter8_exercise1")
setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter8_exercise1")

txtStart("pec_exercise_R.txt")

#---- Load in data ----
data <- read_dta('pec_BJPS.dta')

#---- Create some variables ----
data <- data %>%
  mutate(coalitionseatlag = seatlag1 + seatlag2,
         seatshare = coalitionseatlag*100,
         seatshare_2 = seatshare*seatshare,
         polarization_threshold = polarization*threshold) %>%
  apply_labels(seatshare = "size of potential coalition in percentage of seats",
               seatshare_2 = "seatshare squared")

#---- Produce results shown in Table 8.3 in Chapter 8 ----
mod1 <- glm(pec ~ threshold + polarization + polarization_threshold + incompatibility, 
            family = "binomial", data); summary(mod1)
exp(cbind(OR = coef(mod1), confint(mod1)))

#---- Calculate marginal effect of Ideological Incompatibility when	Disproportionality is 5, Polarization is 24.68, and Ideological	Incompatibility is 19.51. ----

#---- Use R's automated commands.	----
summary(margins(mod1, at = list(threshold = 5, polarization = 24.68, polarization_threshold = 123.4, incompatibility = 19.51), vce = "delta"))

mod2 <- glm(pec ~ threshold*polarization + incompatibility, 
    family = "binomial", data); summary(mod2)
summary(margins(mod2, at = list(threshold = 5, polarization = 24.68, incompatibility = 19.51), vce = "delta"))
#---- Now manually ----
xbeta <- mod1$coefficients[1] + mod1$coefficients[2]*5 + mod1$coefficients[3]*24.68 +
  mod1$coefficients[4]*5*24.68 + mod1$coefficients[5]*19.51; xbeta
lambda <- exp(xbeta)/(1+exp(xbeta)); lambda
1-lambda  

#---- Marginal effect of Ideological Incompatibility in chosen scenario ----
me_incompatibility <- lambda*(1-lambda)*mod1$coefficients[5]; me_incompatibility

#---- Largest marginal effect of ideological incompatibility ----
me_incompatibility_max <- 0.5*0.5*mod1$coefficients[5]; me_incompatibility_max

#---- Marginal effect of Disproportionality in chosen scenario ----
me_disproportionality <- lambda*(1-lambda)*(mod1$coefficients[2] + mod1$coefficients[4]*24.68); me_disproportionality

#---- Marginal effect of Polarization in chosen scenario ----
me_polarization <- lambda*(1-lambda)*(mod1$coefficients[3] + mod1$coefficients[4]*5); me_polarization

#---- Calculate interaction effect of Disproportionality and Polarization in chosen scenario ----
lambda*(1-lambda)*mod1$coefficients[4] + lambda*(1-lambda)*(1-2*lambda)*
  (mod1$coefficients[2]+mod1$coefficients[4]*24.68)*(mod1$coefficients[3]+mod1$coefficients[4]*5)

#---- Calculate change and percentage change in the probability of PEC formation when we increase Polarization by 10 units when Polarization is 15, Disproportionality is 2, and Ideological Incompatibility is 24 ----
  
#---- Predicted probability when Disproportionality is 2, Polarization is 15, and Ideological Incompatibility is 24 ----

#---- Use R's automated commands ----
summary(mod1)
b <- coef(mod1)
v <- vcov(mod1)
exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
      mod1$coefficients[4]*30+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                mod1$coefficients[4]*30+mod1$coefficients[5]*24))
deltamethod(~exp(x1+x2*2+x3*15+x4*30+x5*24)/
              (1+exp(x1+x2*2+x3*15+x4*30+x5*24)), b, v)

summary(mod2)  
predict(mod2, newdata = data.frame(threshold = 2, polarization = 15, 
                                      incompatibility = 24), se.fit=TRUE, interval="confidence", type = "response")  
  
#---- Now manually ----
xbeta <- mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
               mod1$coefficients[4]*30+mod1$coefficients[5]*24; xbeta
lambda <- exp(xbeta)/(1+exp(xbeta)); lambda

#---- Using values provided in the book ----
exp(-3.3622)/(1+exp(-3.3622))

#---- Predicted probability when Disproportionality is 2, Polarization is 25, and Ideological Incompatibility is 24 ----

#---- Use R's automated commands.	 ----
summary(mod2)
predict(mod2, newdata = data.frame(threshold = 2, polarization = 25, 
                                   incompatibility = 24), se.fit=TRUE, interval="confidence", type ="response")  
summary(mod1)
exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
      mod1$coefficients[4]*2*25+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
                                                                  mod1$coefficients[4]*2*25+mod1$coefficients[5]*24))
deltamethod(~exp(x1+x2*2+x3*25+x4*50+x5*24)/
              (1+exp(x1+x2*2+x3*25+x4*50+x5*24)), b, v)

#---- Now manually ----
xbeta2 <- mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
  mod1$coefficients[4]*2*25+mod1$coefficients[5]*24; xbeta2
lambda2 <- exp(xbeta2)/(1+exp(xbeta2)); lambda2

#---- Using values provided in the book ----
exp(-3.3152)/(1+exp(-3.3152))

#---- Change in probability across the two scenarios when Polarization goes from 15 to 25 ----
summary(mod1)
exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
      mod1$coefficients[4]*2*25+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
                                                                  mod1$coefficients[4]*2*25+mod1$coefficients[5]*24))- exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
      mod1$coefficients[4]*30+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                mod1$coefficients[4]*30+mod1$coefficients[5]*24))
deltamethod(~exp(x1+x2*2+x3*25+x4*50+x5*24)/
              (1+exp(x1+x2*2+x3*25+x4*50+x5*24)) - exp(x1+x2*2+x3*15+x4*30+x5*24)/
              (1+exp(x1+x2*2+x3*15+x4*30+x5*24)), b, v)

#---- Now manually ----
lambda2 - lambda
((lambda2-lambda)/lambda)*100

#---- Using values provided in the book ----
(exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)))

(((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622))))/
    (exp(-3.3622)/(1+exp(-3.3622))))*100
  
#---- Calculate change and percentage change in the probability of PEC formation when we increase Polarization by 10 units when	Polarization is 15, Disproportionality is 10, and Ideological	Incompatibility is 24 ----

#---- Predicted probability when Disproportionality is 10, Polarization is 15, and Ideological Incompatibility is 24 ----
  
#---- Use R's automated commands. ----
summary(mod1)

exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
      mod1$coefficients[4]*150+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
                                                                 mod1$coefficients[4]*150+mod1$coefficients[5]*24))
deltamethod(~exp(x1+x2*10+x3*15+x4*150+x5*24)/
              (1+exp(x1+x2*10+x3*15+x4*150+x5*24)), b, v)
summary(mod2)  
predict(mod2, newdata = data.frame(threshold = 10, polarization = 15, 
                                   incompatibility = 24), se.fit=TRUE, interval="confidence", type = "response")  
#---- Now manually ----
xbeta3 <- mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
  mod1$coefficients[4]*150+mod1$coefficients[5]*24; xbeta3
lambda3 <- exp(xbeta3)/(1+exp(xbeta3)); lambda3

#---- Using values provided in the book ----
exp(-3.0782)/(1+exp(-3.0782))

#---- Predicted probability when Disproportionality is 10, Polarization is 25, and Ideological Incompatibility is 24 ----

#---- Use R's automated commands. ----
summary(mod1)

exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
      mod1$coefficients[4]*250+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
                                                                 mod1$coefficients[4]*250+mod1$coefficients[5]*24))
deltamethod(~exp(x1+x2*10+x3*25+x4*250+x5*24)/
              (1+exp(x1+x2*10+x3*25+x4*250+x5*24)), b, v)

summary(mod2)
predict(mod2, newdata = data.frame(threshold = 10, polarization = 25, 
                                   incompatibility = 24), se.fit=TRUE, interval="confidence", type = "response")  

#---- Now manually ----
xbeta4 <- mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
  mod1$coefficients[4]*250+mod1$coefficients[5]*24; xbeta4
lambda4 <- exp(xbeta4)/(1+exp(xbeta4)); lambda4

#---- Using values provided in the book ----
exp(-2.9912)/(1+exp(-2.9912))

#---- Change in probability across the two new scenarios when Polarization goes from 15 to 25	----

#---- Use R's automated commands. ----
summary(mod1)
exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
      mod1$coefficients[4]*250+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
                                                                 mod1$coefficients[4]*250+mod1$coefficients[5]*24)) -
  exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
        mod1$coefficients[4]*150+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
                                                                   mod1$coefficients[4]*150+mod1$coefficients[5]*24)) 
deltamethod(~exp(x1+x2*10+x3*25+x4*250+x5*24)/
              (1+exp(x1+x2*10+x3*25+x4*250+x5*24)) -
              exp(x1+x2*10+x3*15+x4*150+x5*24)/
              (1+exp(x1+x2*10+x3*15+x4*150+x5*24)), b, v)

summary(mod2)

#---- Now manually ----
lambda4 - lambda3
((lambda4-lambda3)/lambda3)*100

#---- Using values provided in the book ----
(exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782)))

(((exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782))))/(exp(-3.0782)/(1+exp(-3.0782))))*100

#---- Modifying effect of disproportionality going from 2 to 10 on the effect of increasing polarization from 15 to 25 ----
summary(mod1)

#---- Use R's automated commands. ----
summary(mod1)
(exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
       mod1$coefficients[4]*250+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
                                                                  mod1$coefficients[4]*250+mod1$coefficients[5]*24)) -
    exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
          mod1$coefficients[4]*150+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
                                                                     mod1$coefficients[4]*150+mod1$coefficients[5]*24))) -
  (exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
         mod1$coefficients[4]*2*25+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
                                                                     mod1$coefficients[4]*2*25+mod1$coefficients[5]*24))- exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                mod1$coefficients[4]*30+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                                                                          mod1$coefficients[4]*30+mod1$coefficients[5]*24)))
deltamethod(~(exp(x1+x2*10+x3*25+x4*250+x5*24)/
              (1+exp(x1+x2*10+x3*25+x4*250+x5*24)) -
              exp(x1+x2*10+x3*15+x4*150+x5*24)/
              (1+exp(x1+x2*10+x3*15+x4*150+x5*24))) -
              (exp(x1+x2*2+x3*25+x4*50+x5*24)/
              (1+exp(x1+x2*2+x3*25+x4*50+x5*24)) - exp(x1+x2*2+x3*15+x4*30+x5*24)/
              (1+exp(x1+x2*2+x3*15+x4*30+x5*24))), b, v)

((exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
       mod1$coefficients[4]*250+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*25+
                                                                  mod1$coefficients[4]*250+mod1$coefficients[5]*24)) -
    exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
          mod1$coefficients[4]*150+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*10+mod1$coefficients[3]*15+
                                                                     mod1$coefficients[4]*150+mod1$coefficients[5]*24))) -
  (exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
         mod1$coefficients[4]*2*25+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
                                                                     mod1$coefficients[4]*2*25+mod1$coefficients[5]*24))- exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                mod1$coefficients[4]*30+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                                                                          mod1$coefficients[4]*30+mod1$coefficients[5]*24)))) /
  (exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
         mod1$coefficients[4]*2*25+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*25+
                                                                     mod1$coefficients[4]*2*25+mod1$coefficients[5]*24))- exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                mod1$coefficients[4]*30+mod1$coefficients[5]*24)/(1+exp(mod1$coefficients[1]+mod1$coefficients[2]*2+mod1$coefficients[3]*15+
                                                                                                                                                                                          mod1$coefficients[4]*30+mod1$coefficients[5]*24))) *100
deltamethod(~((exp(x1+x2*10+x3*25+x4*250+x5*24)/
                (1+exp(x1+x2*10+x3*25+x4*250+x5*24)) -
                exp(x1+x2*10+x3*15+x4*150+x5*24)/
                (1+exp(x1+x2*10+x3*15+x4*150+x5*24))) -
              (exp(x1+x2*2+x3*25+x4*50+x5*24)/
                 (1+exp(x1+x2*2+x3*25+x4*50+x5*24)) - exp(x1+x2*2+x3*15+x4*30+x5*24)/
                 (1+exp(x1+x2*2+x3*15+x4*30+x5*24))))/
              ((exp(x1+x2*2+x3*25+x4*50+x5*24)/
                  (1+exp(x1+x2*2+x3*25+x4*50+x5*24)) - exp(x1+x2*2+x3*15+x4*30+x5*24)/
                  (1+exp(x1+x2*2+x3*15+x4*30+x5*24))))*100, b, v)

#---- Now manually ----
(lambda4-lambda3)-(lambda2-lambda)
(((lambda4-lambda3)-(lambda2-lambda))/(lambda2-lambda)*100)

#---- Using values provided in the book ----
((((exp(-2.9912)/(1+exp(-2.9912)))-(exp(-3.0782)/(1+exp(-3.0782))))-((exp(-3.3152)/
      (1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)))))/((exp(-3.3152)/(1+exp(-3.3152)))-(exp(-3.3622)/(1+exp(-3.3622)))))*100

#---- Calculate the change and percentage change in the odds of PEC	formation associated with increasing Disproportionality by 5 units when Polarization is 10 ----
summary(mod1)

#---- Use R's automated commands ----
exp((mod1$coefficients[2]+mod1$coefficients[4]*10)*5)
deltamethod(~exp((x2+x4*10)*5), b, v)

#---- Now manually ----
exp((mod1$coefficients[2] + mod1$coefficients[4]*10)*5)

#---- Using values provided in the book ----
exp((0.0280+0.0005*10)*5)

#---- Calculate the change and percentage change in the odds of PEC	formation associated with increasing Disproportionality by 5 units when Polarization is 30 ----
summary(mod1)

#---- Use R's automated commands ----
exp((mod1$coefficients[2]+mod1$coefficients[4]*30)*5)
deltamethod(~exp((x2+x4*30)*5), b, v)

#---- Now manually ----
exp((mod1$coefficients[2] + mod1$coefficients[4]*30)*5)

#---- Using values provided in the book ----
exp((0.0280+0.0005*30)*5)

#---- Modifying effect of increasing Polarization from 10 to 30 ----
(exp((mod1$coefficients[2] + mod1$coefficients[4]*30)*5) - exp((mod1$coefficients[2] + mod1$coefficients[4]*10)*5)) /
  exp((mod1$coefficients[2] + mod1$coefficients[4]*10)*5) * 100

#---- Using values provided in the book ----
(((exp((0.0280+0.0005*30)*5))-(exp((0.0280+0.0005*10)*5)))/
   (exp((0.0280+0.0005*10)*5)))*100

txtStop()