# Install required packages (uncomment if needed)
#install.packages(c("haven", "tidyverse", "psych", "multcomp", "MASS", "aod", "msm", "TeachingDemos"))

# Load required libraries
library(haven) #to read in .dta (Stata) files
library(tidyverse) #for data manipulation and ggplot
library(psych) #to describe data
library(multcomp) #for glht
library(MASS) #polr
library(aod) #for wald.test
library(msm) #for deltamethod
library(TeachingDemos) #for txtStart

# Set working directory
setwd("~/Dropbox/ali/replications/chapter9_application")
#setwd("C:/Users/alikagalwala/Dropbox/ali/replications/chapter9_application")

txtStart("approval_collectdata_R.txt")

#---- Load in data ----
data <- read_dta('anes2012_small.dta')

#---- Variable description ----
names(data)
describe(data)

#---- Drop respondents who are not white or black ----
data <- filter(data, white == 1 | black == 1)

#---- interaction term for race and ideological distance ----
data$black_leftright = data$left_right * data$black

#---- Produce results shown in Table 9.1 in Chapter 9	----
mod1 <- polr(as.factor(obama_approval) ~ left_right + black + black_leftright +
             worse_off_national + female + age, data)
summary(mod1)

#---- Get odds ratios ----
summary(mod1)
low <- exp(mod1$coefficients[2] + mod1$coefficients[3]*1); low
hi <- exp(mod1$coefficients[2] + mod1$coefficients[3]*7); hi
hi/low

odds_hat <- vector()
odds_lo <- vector()
odds_hi <- vector() 	
a <- 0
j <- 1
while(a <= 7.1){
  
  odds_lo[j] <- exp((mod1$coefficients[2] + mod1$coefficients[3]*a) - qnorm(0.975)*deltamethod(~ (x2 + x3*a), summary(mod1)$coefficients[, 1], vcov(mod1)))
  odds_hi[j] <- exp((mod1$coefficients[2] + mod1$coefficients[3]*a) + qnorm(0.975)*deltamethod(~ (x2 + x3*a), summary(mod1)$coefficients[, 1], vcov(mod1)))
  odds_hat[j] <- exp(mod1$coefficients[2] + mod1$coefficients[3]*a)
  a <- a + 0.1
  j <- j + 1
  
}

n <- 1:72
MV <- (n-1)/10

odds_percent <- (odds_hat-1)*100
odds_percent_lo <- (odds_lo-1)*100
odds_percent_hi <- (odds_hi-1)*100

odds <- as.data.frame(cbind(MV, odds_hat, odds_lo, odds_hi, odds_percent, odds_percent_lo, odds_percent_hi))
odds <- filter(odds, MV>0.9 & MV<7.1)
write_csv(odds, 'odds_R.csv')

txtStop()